package com.sztzjy.digital_credit.controller;

import com.github.pagehelper.PageInfo;
import com.nimbusds.jose.shaded.gson.Gson;
import com.sztzjy.digital_credit.annotation.AnonymousAccess;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.entity.dto.StuFinancialIndexDTO;
import com.sztzjy.digital_credit.service.StuEnterPriseByInfoEntryService;
import com.sztzjy.digital_credit.util.ResultEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.constraints.NotBlank;
import java.util.List;

/**
 * @author 17803
 * @date 2024-04-11 14:57
 */
@Api(tags = "企业征信:信息录入")
@RestController
@RequestMapping("api/stu/infoEntry")
public class StuEnterPriseByInfoEntryController {


    @Autowired
    private StuEnterPriseByInfoEntryService infoEntryService;


    @ApiOperation("基本信息查询")
    @AnonymousAccess
    @GetMapping("/getBaseInfo")
    public ResultEntity getBaseInfo(@NotBlank String userId){
        return infoEntryService.getBaseInfo(userId);

    }


    @ApiOperation("基本信息自动保存（未提交算分）")
    @AnonymousAccess
    @PostMapping("/saveInfoByAuto")
    public ResultEntity saveInfoByAuto(@RequestBody @ApiParam("id不用传参") StuBaseInfo stuBaseInfo){
        return infoEntryService.saveInfoByAuto(stuBaseInfo);

    }



    @ApiOperation("基本信息提交（算分）")
    @AnonymousAccess
    @PostMapping("/subBaseInfo")
    public ResultEntity subBaseInfo(@RequestBody StuBaseInfo stuBaseInfo){
        return infoEntryService.subBaseInfo(stuBaseInfo);

    }






    @ApiOperation("信贷记录查询")
    @AnonymousAccess
    @GetMapping("/getCreditRecordsInfo")
    public ResultEntity getCreditRecordsInfo(@NotBlank String userId){
        return infoEntryService.getCreditRecordsInfo(userId);

    }





    @ApiOperation("信贷记录自动保存（未提交算分）")
    @AnonymousAccess
    @PostMapping("/saveCreditRecordsInfoByAuto")
    public ResultEntity saveCreditRecordsInfoByAuto(@RequestBody @ApiParam("id不用传参") StuCreditRecords creditRecords){
        return infoEntryService.saveCreditRecordsInfoByAuto(creditRecords);

    }


    @ApiOperation("信贷记录提交（算分）")
    @AnonymousAccess
    @PostMapping("/subCreditRecordsBaseInfo")
    public ResultEntity subCreditRecordsBaseInfo(@RequestBody StuCreditRecords creditRecords){
        return infoEntryService.subCreditRecordsBaseInfo(creditRecords);

    }




    @PostMapping("/importFinancialStatements")
    @ApiOperation("批量导入财务报表")
    @AnonymousAccess
    public ResultEntity importFinancialStatements(@RequestParam(required = false) @RequestPart MultipartFile file,
                                                                   @ApiParam("资产负债表/现金流量表/利润表") @RequestParam(required = false) String module) {


        return   infoEntryService.importFinancialStatements(file,module);

    }


    @ApiOperation("查询财务报表")
    @AnonymousAccess
    @GetMapping("/getFinancialStatementsInfoDetails")
    public ResultEntity<PageInfo> getFinancialStatementsInfoDetails(@RequestParam(defaultValue = "1",required = true,name = "page") @NotBlank Integer page,
                                                                    @RequestParam(defaultValue = "10",required = true,name = "size") @NotBlank Integer size
                                            ,@NotBlank String module){
        return infoEntryService.getFinancialStatementsInfoDetails(page,size,module);

    }





    @ApiOperation("财务指标全部查询")
    @AnonymousAccess
    @GetMapping("/getFinancialIndex")
    public ResultEntity<StuFinancialIndexDTO> getFinancialIndex(@NotBlank String userId){
        return infoEntryService.getFinancialIndex(userId);

    }




    @ApiOperation("财务指标盈利能力自动保存")
    @AnonymousAccess
    @PostMapping("/getFinancialProfitAbilityByAuto")
    public ResultEntity getFinancialProfitAbilityByAuto(@RequestBody StuProfitAbility profitAbility){
        return infoEntryService.getFinancialProfitAbilityByAuto(profitAbility);

    }


    @ApiOperation("财务指标盈利能力提交算分")
    @AnonymousAccess
    @PostMapping("/getFinancialProfitAbilityBySub")
    public ResultEntity getFinancialProfitAbilityBySub(@RequestBody StuProfitAbility profitAbility){
        return infoEntryService.getFinancialProfitAbilityBySub(profitAbility);

    }

    @ApiOperation("财务指标偿债能力自动保存")
    @AnonymousAccess
    @PostMapping("/getFinancialSolvencyByAuto")
    public ResultEntity getFinancialSolvencyByAuto(@RequestBody StuSolvency solvency){
        return infoEntryService.getFinancialSolvencyByAuto(solvency);

    }


    @ApiOperation("财务指标偿债能力提交算分")
    @AnonymousAccess
    @PostMapping("/getFinancialSolvencyBySub")
    public ResultEntity getFinancialSolvencyBySub(@RequestBody StuSolvency solvency){
        return infoEntryService.getFinancialSolvencyBySub(solvency);

    }





    @ApiOperation("财务指标营运能力自动保存")
    @AnonymousAccess
    @PostMapping("/getFinancialOperatingCapacityByAuto")
    public ResultEntity getFinancialOperatingCapacityByAuto(@RequestBody StuOperatingCapacity operatingCapacity){
        return infoEntryService.getFinancialOperatingCapacityByAuto(operatingCapacity);

    }


    @ApiOperation("财务指标营运能力提交算分")
    @AnonymousAccess
    @PostMapping("/financialOperatingCapacityBySub")
    public ResultEntity financialOperatingCapacityBySub(@RequestBody StuOperatingCapacity operatingCapacity){
        return infoEntryService.financialOperatingCapacityBySub(operatingCapacity);

    }



    @ApiOperation("财务指标成长能力自动保存")
    @AnonymousAccess
    @PostMapping("/getFinancialGrowthAbilityByAuto")
    public ResultEntity getFinancialGrowthAbilityByAuto(@RequestBody StuGrowthAbility growthAbility){
        return infoEntryService.getFinancialGrowthAbilityByAuto(growthAbility);

    }


    @ApiOperation("财务指标成长能力提交算分")
    @AnonymousAccess
    @PostMapping("/getFinancialGrowthAbilityBySub")
    public ResultEntity getFinancialGrowthAbilityBySub(@RequestBody StuGrowthAbility growthAbility){
        return infoEntryService.getFinancialGrowthAbilityBySub(growthAbility);

    }



    @ApiOperation("财务指标杜邦分析自动保存")
    @AnonymousAccess
    @PostMapping("/getFinancialDuPontAnalysisByAuto")
    public ResultEntity getFinancialDuPontAnalysisByAuto(@RequestBody StuDuPontAnalysis duPontAnalysis){
        return infoEntryService.getFinancialDuPontAnalysisByAuto(duPontAnalysis);

    }




    @ApiOperation("财务指标杜邦分析提交算分")
    @AnonymousAccess
    @PostMapping("/getFinancialDuPontAnalysisBySub")
    public ResultEntity getFinancialDuPontAnalysisBySub(@RequestBody StuDuPontAnalysis duPontAnalysis){
        return infoEntryService.getFinancialDuPontAnalysisBySub(duPontAnalysis);

    }




}
