package com.sztzjy.digital_credit.controller;

import com.itextpdf.text.pdf.parser.PathConstructionRenderInfo;
import com.sztzjy.digital_credit.annotation.AnonymousAccess;
import com.sztzjy.digital_credit.config.Constant;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.service.StuPersonalCreditReportingService;
import com.sztzjy.digital_credit.service.StuRateService;
import com.sztzjy.digital_credit.util.ResultEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.NotBlank;

/**
 * @author tz
 * @date 2024/4/15 10:28
 */
@Api(tags = "个人征信")
@RestController
@RequestMapping("api/stu/personal/infoEntry")
public class StuPersonalInfoEntryController {
    @Resource
    StuPersonalCreditReportingService reportingService;
    @Resource
    StuRateService rateService;


    @ApiOperation("案例详情展示")
    @AnonymousAccess
    @PostMapping("/getCaseDetails")
    public ResultEntity getCaseDetails(){
        String caseDetails = Constant.CASE_DETAILS;
        return new ResultEntity<>(HttpStatus.OK,"成功",caseDetails);
    }


    @ApiOperation("个人信息--查询")
    @AnonymousAccess
    @PostMapping("/getPersonalInfo")
    public ResultEntity getPersonalInfo(@NotBlank String userId){
        StuPersonalInfo stuPersonalInfo=reportingService.getPersonalInfo(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功",stuPersonalInfo);
    }


    @ApiOperation("个人信息--保存")
    @AnonymousAccess
    @PostMapping("/servePersonalInfo")
    public ResultEntity servePersonalInfo(@RequestBody StuPersonalInfo stuPersonalInfo){
        reportingService.servePersonalInfo(stuPersonalInfo);
        return new ResultEntity<>(HttpStatus.OK,"保存成功");
    }


    @ApiOperation("个人信息--提交并计分(自动保存)")
    @AnonymousAccess
    @PostMapping("/submitPersonalInfo")
    public ResultEntity submitPersonalInfo(@RequestBody StuPersonalInfo stuPersonalInfo,String module){
        reportingService.submitPersonalInfo(stuPersonalInfo,module);
        return new ResultEntity<>(HttpStatus.OK,"提交成功");
    }


    @ApiOperation("信用记录--信用提示查询")
    @AnonymousAccess
    @PostMapping("/getCreditReminder")
    public ResultEntity getCreditReminder(@NotBlank String userId){
        StuPersonalCreditReminderInfo constructionRenderInfo=reportingService.getCreditReminder(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功",constructionRenderInfo);
    }

    @ApiOperation("信用记录--信用提示保存")
    @AnonymousAccess
    @PostMapping("/serveCreditReminder")
    public ResultEntity serveCreditReminder(@RequestBody StuPersonalCreditReminderInfo creditReminderInfo){
        reportingService.serveCreditReminder(creditReminderInfo);
        return new ResultEntity<>(HttpStatus.OK,"保存成功");
    }

    @ApiOperation("信用记录--信用提示提交并计分(自动保存)")
    @AnonymousAccess
    @PostMapping("/submitCreditReminder")
    public ResultEntity submitCreditReminder(@RequestBody StuPersonalCreditReminderInfo creditReminderInfo,String module){
        reportingService.submitCreditReminder(creditReminderInfo,module);
        return new ResultEntity<>(HttpStatus.OK,"提交成功");
    }


    @ApiOperation("信用记录--逾期及违约信息概要查询")
    @AnonymousAccess
    @PostMapping("/getOverdueInfo")
    public ResultEntity getOverdueInfo(@NotBlank String userId){
        StuPersonalDefaultInfo stuPersonalDefaultInfo=reportingService.getOverdueInfo(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功",stuPersonalDefaultInfo);
    }

    @ApiOperation("信用记录--逾期及违约信息保存")
    @AnonymousAccess
    @PostMapping("/serveOverdueInfo")
    public ResultEntity serveOverdueInfo(@RequestBody StuPersonalDefaultInfo stuPersonalDefaultInfo){
        reportingService.serveOverdueInfo(stuPersonalDefaultInfo);
        return new ResultEntity<>(HttpStatus.OK,"保存成功");
    }

    @ApiOperation("信用记录--逾期及违约信息提交并计分(自动保存)")
    @AnonymousAccess
    @PostMapping("/submitOverdueInfo")
    public ResultEntity submitOverdueInfo(@RequestBody StuPersonalDefaultInfo stuPersonalDefaultInfo,String module){
        reportingService.submitOverdueInfo(stuPersonalDefaultInfo,module);
        return new ResultEntity<>(HttpStatus.OK,"提交成功");
    }


    @ApiOperation("信用记录--授信及负债信息概要查询")
    @AnonymousAccess
    @PostMapping("/getCreditGranting")
    public ResultEntity getCreditGranting(@NotBlank String userId){
        StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo=reportingService.getCreditGranting(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功",stuPersonalOutstandingLoansInfo);
    }

    @ApiOperation("信用记录--授信及负债信息概要保存")
    @AnonymousAccess
    @PostMapping("/serveCreditGranting")
    public ResultEntity serveCreditGranting(@RequestBody StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo){
        reportingService.serveCreditGranting(stuPersonalOutstandingLoansInfo);
        return new ResultEntity<>(HttpStatus.OK,"保存成功");
    }

    @ApiOperation("信用记录--授信及负债信息概要提交并计分(自动保存)")
    @AnonymousAccess
    @PostMapping("/submitCreditGranting")
    public ResultEntity submitCreditGranting(@RequestBody StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo,String module){
        reportingService.submitCreditGranting(stuPersonalOutstandingLoansInfo,module);
        return new ResultEntity<>(HttpStatus.OK,"提交成功");
    }



    @ApiOperation("信用评分查询")
    @AnonymousAccess
    @PostMapping("/getCreditScore")
    public ResultEntity getCreditScore(@NotBlank String userId){
        StuCreditScore stuCreditScore=reportingService.getCreditScore(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功",stuCreditScore);
    }

    @ApiOperation("信用评分保存")
    @AnonymousAccess
    @PostMapping("/serveCreditScore")
    public ResultEntity serveCreditScore(@RequestBody StuCreditScore stuCreditScore){
        reportingService.serveCreditScore(stuCreditScore);
        return new ResultEntity<>(HttpStatus.OK,"保存成功");
    }

    @ApiOperation("信用评分提交并计分(自动保存)")
    @AnonymousAccess
    @PostMapping("/submitCreditScore")
    public ResultEntity submitCreditScore(@RequestBody StuCreditScore stuCreditScore,String module){
        reportingService.submitCreditScore(stuCreditScore,module);
        return new ResultEntity<>(HttpStatus.OK,"提交成功");
    }


    @ApiOperation("增信方案(自动评分)")
    @AnonymousAccess
    @PostMapping("/serveCreditEnhancement")
    public ResultEntity serveCreditEnhancement(@RequestBody StuCreditEnhanceMeasure enhanceMeasure){
        return  rateService.enhanceMeasureByAutoRating(enhanceMeasure);
    }


    @ApiOperation("个人征信--重新实训")
    @AnonymousAccess
    @PostMapping("/againTraining")
    public ResultEntity againTraining(@NotBlank String userId){
        reportingService.againTraining(userId);
        return new ResultEntity<>(HttpStatus.OK,"成功");
    }
}
