package com.sztzjy.digital_credit.service;

import com.github.pagehelper.PageInfo;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.entity.dto.StuFinancialIndexDTO;
import com.sztzjy.digital_credit.util.ResultEntity;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author 17803
 * @date 2024-04-11 15:02
 */
public interface StuEnterPriseByInfoEntryService {

    /**
        * 基本信息查询
        * @param userId
        * @return
    */

    ResultEntity getBaseInfo(String userId);


    /**
        * 基本信息自动保存（未提交算分）
        * @param stuBaseInfo
        * @return
    */

    ResultEntity saveInfoByAuto(StuBaseInfo stuBaseInfo);

    /**
        * 基本信息提交（算分）
        * @param stuBaseInfo
        * @return
    */

    ResultEntity subBaseInfo(StuBaseInfo stuBaseInfo);

    /**
        * 信贷记录查询
        * @param userId
        * @return
    */

    ResultEntity getCreditRecordsInfo(String userId);

    /**
        * 信贷记录自动保存（未提交算分）
        * @param creditRecords
        * @return
    */

    ResultEntity saveCreditRecordsInfoByAuto(StuCreditRecords creditRecords);


    /**
        * 信贷记录提交（算分）
        * @param creditRecords
        * @return
    */

    ResultEntity subCreditRecordsBaseInfo(StuCreditRecords creditRecords);

    /**
        * 批量导入财务报表
        * @param file
	* @param module
        * @return
    */

    ResultEntity importFinancialStatements(MultipartFile file, String module);



    /**
        * 查询财务报表
        * @param module
        * @return
    */

    ResultEntity<PageInfo> getFinancialStatementsInfoDetails(Integer page, Integer size, String module);


    /**
        * 财务指标
        * @param userId
        * @return
    */

    ResultEntity<StuFinancialIndexDTO> getFinancialIndex(String userId);

    /**
        * 财务指标盈利能力
        * @param profitAbility
        * @return
    */

    ResultEntity getFinancialProfitAbilityByAuto(StuProfitAbility profitAbility);

    /**
        * 财务指标盈利能力提交算分
        * @param profitAbility
        * @return
    */

    ResultEntity getFinancialProfitAbilityBySub(StuProfitAbility profitAbility);


    /**
     * 财务指标偿债能力自动保存
     * @param solvency
     * @return
     */
    ResultEntity getFinancialSolvencyByAuto(StuSolvency solvency);


    /**
        * 财务指标偿债能力提交算分
        * @param solvency
        * @return
    */

    ResultEntity getFinancialSolvencyBySub(StuSolvency solvency);

    /**
        * 财务指标营运能力自动保存
        * @param operatingCapacity
        * @return
    */

    ResultEntity getFinancialOperatingCapacityByAuto(StuOperatingCapacity operatingCapacity);

    /**
        * 财务指标营运能力提交算分
        * @param operatingCapacity
        * @return
    */

    ResultEntity financialOperatingCapacityBySub(StuOperatingCapacity operatingCapacity);

    /**
        * 财务指标成长能力自动保存
        * @param growthAbility
        * @return
    */

    ResultEntity getFinancialGrowthAbilityByAuto(StuGrowthAbility growthAbility);

    /**
        * 财务指标成长能力提交算分
        * @param growthAbility
        * @return
    */

    ResultEntity getFinancialGrowthAbilityBySub(StuGrowthAbility growthAbility);

    /**
        * 财务指标杜邦分析自动保存
        * @param duPontAnalysis
        * @return
    */

    ResultEntity getFinancialDuPontAnalysisByAuto(StuDuPontAnalysis duPontAnalysis);

    /**
        * 财务指标杜邦分析提交算分
        * @param duPontAnalysis
        * @return
    */

    ResultEntity getFinancialDuPontAnalysisBySub(StuDuPontAnalysis duPontAnalysis);
}
