package com.sztzjy.digital_credit.service.impl;
/**
 * @author 17803
 * @date 2024-04-11 15:02
 */

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.util.ListUtils;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.sztzjy.digital_credit.config.Constant;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.entity.dto.StuFinancialIndexDTO;
import com.sztzjy.digital_credit.mapper.*;
import com.sztzjy.digital_credit.service.StuEnterPriseByInfoEntryService;
import com.sztzjy.digital_credit.service.StuRateService;
import com.sztzjy.digital_credit.util.ConvertUtil;
import com.sztzjy.digital_credit.util.MyExcelListener;
import com.sztzjy.digital_credit.util.ResultEntity;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.annotation.Id;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;



@Service
public class StuEnterPriseByInfoEntryServiceImpl implements StuEnterPriseByInfoEntryService {


    @Autowired
    private StuBaseInfoMapper stuBaseInfoMapper;

    @Autowired
    private StuCreditRecordsMapper creditRecordsMapper;

    @Autowired
    private StuFinancialStatementsMapper financialStatementsMapper;


    @Autowired
    private StuDuPontAnalysisMapper duPontAnalysisMapper;

    @Autowired
    private StuProfitAbilityMapper profitAbilityMapper;

    @Autowired
    private StuGrowthAbilityMapper growthAbilityMapper;

    @Autowired
    private StuOperatingCapacityMapper operatingCapacityMapper;



    @Autowired
    private StuSolvencyMapper solvencyMapper;

    @Autowired
    private StuUserMapper userMapper;

    @Autowired
    private StuRateService stuRateService;

    /**
     * 基本信息查询
     * @param userId
     * @return
     */
    @Override
    public ResultEntity getBaseInfo(String userId) {

        StuBaseInfoExample infoExample = new StuBaseInfoExample();
        infoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuBaseInfo> stuBaseInfoList = stuBaseInfoMapper.selectByExample(infoExample);

        if (!stuBaseInfoList.isEmpty()){

            return  new ResultEntity<>(HttpStatus.OK,"获取成功",stuBaseInfoList.get(0));
        }

        return  new ResultEntity<>(HttpStatus.OK,"获取成功");
    }


    /**
        * 基本信息自动保存（未提交算分）
        * @param stuBaseInfo
        * @return
    */

    @Override
    public ResultEntity saveInfoByAuto(StuBaseInfo stuBaseInfo) {


        //传过来用户未提交数据，根据提交状态进行判断，如果已经提交不修改

        StuBaseInfoExample baseInfoExample = new StuBaseInfoExample();
        baseInfoExample.createCriteria().andUserIdEqualTo(stuBaseInfo.getUserId());
        List<StuBaseInfo> stuBaseInfoList = stuBaseInfoMapper.selectByExample(baseInfoExample);
        if (!stuBaseInfoList.isEmpty()){
            StuBaseInfo info = stuBaseInfoList.get(0);

            //防止前端传id为null

            String id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {


                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(stuBaseInfo,info);

            info.setId(id);
            info.setCaseName(Constant.ANLIMINGCHENG);
            info.setCaseDetail(Constant.ANLIINFO);
            info.setCreditCode(Constant.SHEHUIXINYONGDAIMA);
            info.setUpdateTime(new Date());


            stuBaseInfoMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

        //第一次保存没有用户数据


        stuBaseInfo.setId(IdUtil.simpleUUID());
        stuBaseInfo.setCaseName(Constant.ANLIMINGCHENG);
        stuBaseInfo.setCaseDetail(Constant.ANLIINFO);
        stuBaseInfo.setCreditCode(Constant.SHEHUIXINYONGDAIMA);
        stuBaseInfo.setCreateTime(new Date());


        stuBaseInfoMapper.insertSelective(stuBaseInfo);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");
    }

    /**
        * 基本信息提交（算分）
        * @param stuBaseInfo
        * @return
    */

    @Override
    public ResultEntity subBaseInfo(StuBaseInfo stuBaseInfo) {

        //判断是否为第一次提交
        StuBaseInfoExample baseInfoExample = new StuBaseInfoExample();
        baseInfoExample.createCriteria().andUserIdEqualTo(stuBaseInfo.getUserId());
        List<StuBaseInfo> stuBaseInfoList = stuBaseInfoMapper.selectByExample(baseInfoExample);
        if (!stuBaseInfoList.isEmpty()) {
            //有已提交用户数据
            if (stuBaseInfoList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            stuBaseInfo =   resultCheck(stuBaseInfo);
            stuBaseInfo.setUpdateTime(new Date());
            stuBaseInfo.setId(stuBaseInfoList.get(0).getId());
            stuBaseInfoMapper.updateByPrimaryKeySelective(stuBaseInfo);

            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(stuBaseInfo,"基本信息",stuBaseInfo.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",stuBaseInfo.getErrorNumber());

        }else {
            //首次提交判断输入数据是否则正确
            stuBaseInfo =    resultCheck(stuBaseInfo);
            stuBaseInfo.setId(IdUtil.simpleUUID());
            stuBaseInfo.setCreateTime(new Date());

            //插入数据库
            stuBaseInfoMapper.insertSelective(stuBaseInfo);

            stuRateService.enterScoreWriteUserByUserId(stuBaseInfo,"基本信息",stuBaseInfo.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",stuBaseInfo.getErrorNumber());
        }


    }

    /**
        * 信贷记录查询
        * @param userId
        * @return
    */

    @Override
    public ResultEntity getCreditRecordsInfo(String userId) {

        StuCreditRecordsExample creditRecordsExample = new StuCreditRecordsExample();
        creditRecordsExample.createCriteria().andUserIdEqualTo(userId);

        List<StuCreditRecords> stuCreditRecordsList = creditRecordsMapper.selectByExample(creditRecordsExample);

        if (!stuCreditRecordsList.isEmpty()){
            return new ResultEntity<>(HttpStatus.OK,"查询成功！",stuCreditRecordsList.get(0));

        }


        return new ResultEntity<>(HttpStatus.OK,"查询成功！");
    }

    /**
        * 信贷记录自动保存（未提交算分）
        * @param creditRecords
        * @return
    */

    @Override
    public ResultEntity saveCreditRecordsInfoByAuto(StuCreditRecords creditRecords) {
        //查询有无数据，有数据就更新，没有数据就保存
        StuCreditRecordsExample creditRecordsExample = new StuCreditRecordsExample();
        creditRecordsExample.createCriteria().andUserIdEqualTo(creditRecords.getId());

        List<StuCreditRecords> stuCreditRecordsList = creditRecordsMapper.selectByExample(creditRecordsExample);
        if (!stuCreditRecordsList.isEmpty()){
            //更新数据

            StuCreditRecords stuCreditRecords = stuCreditRecordsList.get(0);
            String id = stuCreditRecords.getId();

            BeanUtils.copyProperties(creditRecords,stuCreditRecords);
            stuCreditRecords.setId(id);


            creditRecordsMapper.updateByPrimaryKeySelective(stuCreditRecords);
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        } else {
            //创建数据

            creditRecords.setId(IdUtil.simpleUUID());
            creditRecords.setSubState(0);
            creditRecords.setErrorNumber(0);
            creditRecords.setCreateTime(new Date());

            creditRecordsMapper.insertSelective(creditRecords);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

    }

    /**
        * 信贷记录提交（算分）
        * @param creditRecords
        * @return
    */

    @Override
    public ResultEntity subCreditRecordsBaseInfo(StuCreditRecords creditRecords) {


        StuCreditRecordsExample creditRecordsExample = new StuCreditRecordsExample();
        creditRecordsExample.createCriteria().andUserIdEqualTo(creditRecords.getUserId());

        List<StuCreditRecords> stuCreditRecordsList = creditRecordsMapper.selectByExample(creditRecordsExample);
        if (!stuCreditRecordsList.isEmpty()){

                //已提交
                if (stuCreditRecordsList.get(0).getSubState() == 1){

                    return new ResultEntity<>(HttpStatus.OK);
                }

                //用户已经有了数据、更新

                 //判断结果（错误次数）

                creditRecords =   resultCheckByCreditRecords(creditRecords);
                creditRecords.setId(stuCreditRecordsList.get(0).getId());
                creditRecords.setUpdateTime(new Date());
                creditRecordsMapper.updateByPrimaryKeySelective(creditRecords);

            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(creditRecords,"信贷记录",creditRecords.getUserId());


                return new ResultEntity<>(HttpStatus.OK,"保存成功！",creditRecords.getErrorNumber());

        }else {
            //首次提交插入数据

            creditRecords =   resultCheckByCreditRecords(creditRecords);

            creditRecords.setId(IdUtil.simpleUUID());
            creditRecords.setCreateTime(new Date());
            creditRecordsMapper.insertSelective(creditRecords);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(creditRecords,"信贷记录",creditRecords.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",creditRecords.getErrorNumber());

        }
    }


    /**
        * 批量导入财务报表
        * @param file
	* @param module
        * @return
    */

    @Override
    public ResultEntity importFinancialStatements(MultipartFile file, String module) {


        try {
            //获取文件的输入流
            EasyExcel.read(file.getInputStream(), StuFinancialStatements.class, new MyExcelListener(financialStatementsMapper,module)).sheet().doRead();

            return new ResultEntity(HttpStatus.OK,"导入成功！");

        }catch (IOException exception){
            return new ResultEntity(HttpStatus.BAD_REQUEST,"导入失败！");
        }
    }

    /**
        * 查询财务报表
        * @param module
        * @return
    */

    @Override
    public ResultEntity<PageInfo> getFinancialStatementsInfoDetails(Integer page, Integer size, String module) {

        PageHelper.startPage(page,size);


        StuFinancialStatementsExample financialStatementsExample = new StuFinancialStatementsExample();

        financialStatementsExample.setOrderByClause("serial_number asc");
        financialStatementsExample.createCriteria().andModuleEqualTo(module);


        List<StuFinancialStatements> financialStatementsList = financialStatementsMapper.selectByExample(financialStatementsExample);

        if (!financialStatementsList.isEmpty()){
            PageInfo<StuFinancialStatements> stuFinancialStatementsPageInfo = new PageInfo<>(financialStatementsList);
            return new ResultEntity(HttpStatus.OK,stuFinancialStatementsPageInfo);
        }else {
            return new ResultEntity(HttpStatus.OK);
        }

    }

    /**
        * 财务指标查询
        * @param userId
        * @return
    */

    @Override
    public ResultEntity<StuFinancialIndexDTO> getFinancialIndex(String userId) {

        StuFinancialIndexDTO financialIndexDTO =    duPontAnalysisMapper.selectByAllInfo(userId);


        return new ResultEntity<>(HttpStatus.OK,financialIndexDTO);
    }

    /**
        * 财务指标盈利能力
        * @param profitAbility
        * @return
    */

    @Override
    public ResultEntity getFinancialProfitAbilityByAuto(StuProfitAbility profitAbility) {

        //传过来用户未提交数据，根据提交状态进行判断，如果已经提交不修改

        StuProfitAbilityExample profitAbilityExample = new StuProfitAbilityExample();
        profitAbilityExample.createCriteria().andUserIdEqualTo(profitAbility.getUserId());
        List<StuProfitAbility> profitAbilityList = profitAbilityMapper.selectByExample(profitAbilityExample);
        if (!profitAbilityList.isEmpty()){
            StuProfitAbility info = profitAbilityList.get(0);

            //防止前端传id为null

            Integer id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {

                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(profitAbility,info);

            info.setId(id);


            profitAbilityMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }else {

        //第一次保存没有用户数据


        profitAbility.setId((int) IdUtil.getSnowflakeNextId());



        profitAbilityMapper.insertSelective(profitAbility);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

    }

    /**
        * 财务指标盈利能力提交算分
        * @param profitAbility
        * @return
    */

    @Override
    public ResultEntity getFinancialProfitAbilityBySub(StuProfitAbility profitAbility) {
        //判断是否为第一次提交
        StuProfitAbilityExample profitAbilityExample = new StuProfitAbilityExample();
        profitAbilityExample.createCriteria().andUserIdEqualTo(profitAbility.getUserId());
        List<StuProfitAbility> profitAbilityList = profitAbilityMapper.selectByExample(profitAbilityExample);
        if (!profitAbilityList.isEmpty()){
            //有已提交用户数据
            if (profitAbilityList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            profitAbility =   FinancialProfitAbilityCheck(profitAbility);
            profitAbility.setId(profitAbilityList.get(0).getId());
            profitAbilityMapper.updateByPrimaryKeySelective(profitAbility);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(profitAbility,"盈利能力",profitAbility.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",profitAbility.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            profitAbility =   FinancialProfitAbilityCheck(profitAbility);


            //插入数据库
            profitAbilityMapper.insertSelective(profitAbility);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(profitAbility,"盈利能力",profitAbility.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",profitAbility.getErrorNumber());
        }

    }

    /**
     * 财务指标偿债能力自动保存
     * @param solvency
     * @return
     */
    @Override
    public ResultEntity getFinancialSolvencyByAuto(StuSolvency solvency) {
        //查询有无数据，有数据就更新，没有数据就保存
        StuSolvencyExample solvencyExample = new StuSolvencyExample();
        solvencyExample.createCriteria().andUserIdEqualTo(solvency.getUserId());

        List<StuSolvency> stuSolvencyList = solvencyMapper.selectByExample(solvencyExample);
        if (!stuSolvencyList.isEmpty()){
            //更新数据

            StuSolvency stuSolvency = stuSolvencyList.get(0);
            Integer id = stuSolvency.getId();

            BeanUtils.copyProperties(solvency,stuSolvency);
            stuSolvency.setId(id);


            solvencyMapper.updateByPrimaryKeySelective(stuSolvency);
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        } else {
            //创建数据
            solvency.setSubState(0);
            solvency.setErrorNumber(0);


            solvencyMapper.insertSelective(solvency);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }
    }


    /**
        * 财务指标偿债能力提交算分
        * @param solvency
        * @return
    */

    @Override
    public ResultEntity getFinancialSolvencyBySub(StuSolvency solvency) {
        StuSolvencyExample solvencyExample = new StuSolvencyExample();
        solvencyExample.createCriteria().andUserIdEqualTo(solvency.getUserId());

        List<StuSolvency> stuSolvencyList = solvencyMapper.selectByExample(solvencyExample);
        if (!stuSolvencyList.isEmpty()){

            //已提交
            if (stuSolvencyList.get(0).getSubState() == 1){

                return new ResultEntity<>(HttpStatus.OK);
            }

            //用户已经有了数据、更新

            //判断结果（错误次数）

            solvency =   resultCheckByFinancialSolvency(solvency);
            solvency.setId(stuSolvencyList.get(0).getId());
            solvencyMapper.updateByPrimaryKeySelective(solvency);

            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(solvency,"偿债能力",solvency.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",solvency.getErrorNumber());

        }else {
            //首次提交插入数据

            solvency =   resultCheckByFinancialSolvency(solvency);


            solvencyMapper.insertSelective(solvency);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(solvency,"偿债能力",solvency.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",solvency.getErrorNumber());

        }
    }

    /**
        * 财务指标营运能力自动保存
        * @param operatingCapacity
        * @return
    */

    @Override
    public ResultEntity getFinancialOperatingCapacityByAuto(StuOperatingCapacity operatingCapacity) {
        //查询有无数据，有数据就更新，没有数据就保存
        StuOperatingCapacityExample operatingCapacityExample = new StuOperatingCapacityExample();
        operatingCapacityExample.createCriteria().andUserIdEqualTo(operatingCapacity.getUserId());

        List<StuOperatingCapacity> operatingCapacityList = operatingCapacityMapper.selectByExample(operatingCapacityExample);
        if (!operatingCapacityList.isEmpty()){
            //更新数据

            StuOperatingCapacity stuOperatingCapacity = operatingCapacityList.get(0);
            Integer id = stuOperatingCapacity.getId();

            BeanUtils.copyProperties(operatingCapacity,stuOperatingCapacity);
            stuOperatingCapacity.setId(id);


            operatingCapacityMapper.updateByPrimaryKeySelective(stuOperatingCapacity);
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        } else {
            //创建数据
            operatingCapacity.setSubState(0);
            operatingCapacity.setErrorNumber(0);


            operatingCapacityMapper.insertSelective(operatingCapacity);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }
    }

    /**
        * 财务指标营运能力提交算分
        * @param operatingCapacity
        * @return
    */

    @Override
    public ResultEntity financialOperatingCapacityBySub(StuOperatingCapacity operatingCapacity) {

        //判断是否为第一次提交
        StuOperatingCapacityExample operatingCapacityExample = new StuOperatingCapacityExample();
        operatingCapacityExample.createCriteria().andUserIdEqualTo(operatingCapacity.getUserId());

        List<StuOperatingCapacity> operatingCapacityList = operatingCapacityMapper.selectByExample(operatingCapacityExample);
        if (!operatingCapacityList.isEmpty()){
            //有已提交用户数据
            if (operatingCapacityList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            operatingCapacity =  financialOperatingCapacityCheck(operatingCapacity);
            operatingCapacity.setId(operatingCapacityList.get(0).getId());
            operatingCapacityMapper.updateByPrimaryKeySelective(operatingCapacity);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(operatingCapacity,"营运能力",operatingCapacity.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",operatingCapacity.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            operatingCapacity =  financialOperatingCapacityCheck(operatingCapacity);


            //插入数据库
            operatingCapacityMapper.insertSelective(operatingCapacity);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(operatingCapacity,"营运能力",operatingCapacity.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",operatingCapacity.getErrorNumber());
        }



    }


    /**
        * 财务指标成长能力自动保存
        * @param growthAbility
        * @return
    */

    @Override
    public ResultEntity getFinancialGrowthAbilityByAuto(StuGrowthAbility growthAbility) {

        StuGrowthAbilityExample growthAbilityExample = new StuGrowthAbilityExample();
        growthAbilityExample.createCriteria().andUserIdEqualTo(growthAbility.getUserId());

        List<StuGrowthAbility> growthAbilityList = growthAbilityMapper.selectByExample(growthAbilityExample);
        if (!growthAbilityList.isEmpty()){
            //更新数据

            StuGrowthAbility stuGrowthAbility = growthAbilityList.get(0);
            Integer id = stuGrowthAbility.getId();

            BeanUtils.copyProperties(growthAbility,stuGrowthAbility);
            stuGrowthAbility.setId(id);


            growthAbilityMapper.updateByPrimaryKeySelective(stuGrowthAbility);
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        } else {
            //创建数据
            growthAbility.setSubState(0);
            growthAbility.setErrorNumber(0);


            growthAbilityMapper.insertSelective(growthAbility);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }
    }


    /**
        * 财务指标成长能力提交算分
        * @param growthAbility
        * @return
    */

    @Override
    public ResultEntity getFinancialGrowthAbilityBySub(StuGrowthAbility growthAbility) {

        //判断是否为第一次提交
        StuGrowthAbilityExample growthAbilityExample = new StuGrowthAbilityExample();
        growthAbilityExample.createCriteria().andUserIdEqualTo(growthAbility.getUserId());

        List<StuGrowthAbility> growthAbilityList = growthAbilityMapper.selectByExample(growthAbilityExample);
        if (!growthAbilityList.isEmpty()){
            //有已提交用户数据
            if (growthAbilityList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            growthAbility =  financialGrowthAbilityCheck(growthAbility);
            growthAbility.setId(growthAbilityList.get(0).getId());
            growthAbilityMapper.updateByPrimaryKeySelective(growthAbility);

            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(growthAbility,"成长能力",growthAbility.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",growthAbility.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            growthAbility =  financialGrowthAbilityCheck(growthAbility);

            //插入数据库
            growthAbilityMapper.insertSelective(growthAbility);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(growthAbility,"成长能力",growthAbility.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",growthAbility.getErrorNumber());
        }
    }



    /**
        * 财务指标杜邦分析自动保存
        * @param duPontAnalysis
        * @return
    */

    @Override
    public ResultEntity getFinancialDuPontAnalysisByAuto(StuDuPontAnalysis duPontAnalysis) {

        StuDuPontAnalysisExample duPontAnalysisExample = new StuDuPontAnalysisExample();
        duPontAnalysisExample.createCriteria().andUserIdEqualTo(duPontAnalysis.getUserId());

        List<StuDuPontAnalysis> duPontAnalysisList = duPontAnalysisMapper.selectByExample(duPontAnalysisExample);
        if (!duPontAnalysisList.isEmpty()){
            //更新数据

            StuDuPontAnalysis stuDuPontAnalysis = duPontAnalysisList.get(0);
            Integer id = stuDuPontAnalysis.getId();

            BeanUtils.copyProperties(duPontAnalysis,stuDuPontAnalysis);
            stuDuPontAnalysis.setId(id);


            duPontAnalysisMapper.updateByPrimaryKeySelective(stuDuPontAnalysis);
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        } else {
            //创建数据
            duPontAnalysis.setSubState(0);
            duPontAnalysis.setErrorNumber(0);


            duPontAnalysisMapper.insertSelective(duPontAnalysis);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }
    }

    /**
        * 财务指标杜邦分析提交算分
        * @param duPontAnalysis
        * @return
    */

    @Override
    public ResultEntity getFinancialDuPontAnalysisBySub(StuDuPontAnalysis duPontAnalysis) {



        //判断是否为第一次提交
        StuDuPontAnalysisExample duPontAnalysisExample = new StuDuPontAnalysisExample();
        duPontAnalysisExample.createCriteria().andUserIdEqualTo(duPontAnalysis.getUserId());

        List<StuDuPontAnalysis> duPontAnalysisList = duPontAnalysisMapper.selectByExample(duPontAnalysisExample);
        if (!duPontAnalysisList.isEmpty()){
            //有已提交用户数据
            if (duPontAnalysisList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            duPontAnalysis =  financialDuPontAnalysisCheck(duPontAnalysis);
            duPontAnalysis.setId(duPontAnalysisList.get(0).getId());
            duPontAnalysisMapper.updateByPrimaryKeySelective(duPontAnalysis);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(duPontAnalysis,"杜邦分析",duPontAnalysis.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",duPontAnalysis.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            duPontAnalysis =  financialDuPontAnalysisCheck(duPontAnalysis);

            //插入数据库
            duPontAnalysisMapper.insertSelective(duPontAnalysis);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(duPontAnalysis,"杜邦分析",duPontAnalysis.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",duPontAnalysis.getErrorNumber());
        }
    }

    //财务指标杜邦分析提交算分
    private StuDuPontAnalysis financialDuPontAnalysisCheck(StuDuPontAnalysis duPontAnalysis) {
        int sum = 0;

        //总资产净利率
        if (!"0.05".equals(duPontAnalysis.getNetPrifitMarginTotalAsset())){
            sum  = sum +2;
        }
        //权益净利率
        if (!"0.16".equals(duPontAnalysis.getReturnEquity())){
            sum  = sum +2;
        }


        duPontAnalysis.setSubState(1);
        duPontAnalysis.setErrorNumber(sum);
        return duPontAnalysis;

    }

    //财务指标成长能力提交算分
    private StuGrowthAbility financialGrowthAbilityCheck(StuGrowthAbility growthAbility) {

        int sum = 0;
        if (!"0.09".equals(growthAbility.getYearGrowth())){
            sum ++;
        }



        growthAbility.setErrorNumber(sum);
        growthAbility.setSubState(1);
        return growthAbility;


    }


    //财务指标营运能力提交算分
    private StuOperatingCapacity financialOperatingCapacityCheck(StuOperatingCapacity operatingCapacity) {

        int sum = 0;

        //总资产周转率
        if (!"1.01".equals(operatingCapacity.getTotalAssetTurnover()))
        {
            sum = sum + 2;

        }


        //流动资产周转率
        if (!"3.57".equals(operatingCapacity.getCurrentAssetTurnover()))
        {
            sum = sum + 2;

        }

        //应收账款周转率
        if (!"14.48".equals(operatingCapacity.getAccountsReceivalTurnoverRate()))
        {
            sum = sum + 2;

        }

        //存货周转率
        if (!"10.58".equals(operatingCapacity.getInventoryTurnoverRate()))
        {
            sum = sum + 2;

        }

        operatingCapacity.setErrorNumber(sum);

        operatingCapacity.setSubState(1);

        return operatingCapacity;



    }

    //财务指标偿债能力提交算分
    private StuSolvency resultCheckByFinancialSolvency(StuSolvency solvency) {

       int sum = 0 ;

        if (!solvency.getCurrentRatio().equals("0.47")){
            sum ++;
        }

        if (!solvency.getAssetLiabilityRatio().equals("0.7")){
            sum ++;
        }

        if (!solvency.getEquityRatio().equals("2.34")){
            sum ++;
        }

        if (!solvency.getEquityMultiplier().equals("3.34")){
            sum = sum + 2;
        }

        if (!solvency.getQuickRatio().equals("0.28")){
            sum ++;
        }

        if (!solvency.getCashRatio().equals("0.15")){
            sum ++;
        }

        solvency.setSubState(1);
        solvency.setErrorNumber(sum);


        return solvency;



    }


    //盈利能力计算分数
    private StuProfitAbility   FinancialProfitAbilityCheck(StuProfitAbility profitAbility){


        int sum = 0;

        if (!profitAbility.getGrossMargin().equals("0.35")) {

            sum ++;

        }
        if (!profitAbility.getReturnAssetRoa().equals("0.05")) {

           sum = sum +2;
        }

        if (!profitAbility.getReturnEquityRoe().equals("0.16")) {

            sum = sum +2;

        }

        if (!profitAbility.getNetOperatProfitMargin().equals("0.05")) {

            sum = sum +2;

        }

        profitAbility.setErrorNumber(sum);
        profitAbility.setSubState(1);

        return profitAbility;

    }



    //信贷记录计算分数
    private StuCreditRecords resultCheckByCreditRecords(StuCreditRecords creditRecords) {
        int sum = 0;

        //由资产管理公司处置的债务-笔数
        if (!Constant.ONE.equals(creditRecords.getAssetCompanyDebtNumber())){
            sum++;
        }

        //由资产管理公司处置的债务-余额
        if (!Constant.TWO.equals(creditRecords.getAssetCompanyDebtBalance())){
            sum++;
        }
        //管理公司处置的债务-最近一次处置完成日期
        if (!Constant.THREE.equals(creditRecords.getAssetCompanyDebtDate())){
            sum++;
        }

        //欠息汇总-笔数
        if (!Constant.FOUR.equals(creditRecords.getSummaryOfOutstandInterestNumber())){
            sum++;
        }

        //欠息汇总-余额
        if (!Constant.FIVE.equals(creditRecords.getSummaryOfOutstandInterestBalance())){
            sum++;
        }


        //垫款-笔数
        if (!Constant.SIX.equals(creditRecords.getMakeAdvanceNumber())){
            sum++;
        }

        //垫款-余额
        if (!Constant.SEVEN.equals(creditRecords.getMakeAdvanceBalance())){
            sum++;
        }

        //担保及第三方代偿的债务-笔数
        if (!Constant.EIGHT.equals(creditRecords.getDebtCompensThreePartiesNumber())){
            sum++;
        }

        //担保及第三方代偿的债务-余额
        if (!Constant.NINE.equals(creditRecords.getDebtCompensThreePartiesBalance())){
            sum++;
        }
        //担保及第三方代偿的债务-最近一次还款日期
        if (!Constant.TEN.equals(creditRecords.getDebtCompensThreePartiesDate())){
            sum++;
        }

        //正常类汇总-合计-笔数
        if (!Constant.ELEVEN.equals(creditRecords.getSummaryNormalCategoriesTotalNumber())){
            sum++;
        }

        //正常类汇总-合计-余额
        if (!Constant.TWELVE.equals(creditRecords.getSummaryNormalCategoriesTotalBalance())){
            sum++;
        }

        //关注类汇总-合计-笔数
        if (!Constant.THIRTEEN.equals(creditRecords.getSummaryAttentionCategoriesTotalNumber())){
            sum++;
        }

        //关注类汇总-合计-余额
        if (!Constant.FOURTEEN.equals(creditRecords.getSummaryAttentionCategoriesTotalBalance())){
            sum++;
        }

        //不良/违约类汇总-合计-笔数
        if (!Constant.FIFTEEN.equals(creditRecords.getSummaryDefaultCategoriesTotalNumber())){
            sum++;
        }

        //不良/违约类汇总-合计-余额
        if (!Constant.SIXTEEN.equals(creditRecords.getSummaryDefaultCategoriesTotalBalance())){
            sum++;
        }



        creditRecords.setErrorNumber(sum);
        creditRecords.setSubState(1);


        return creditRecords;
    }



    //基本信息计算分数
    private StuBaseInfo resultCheck(StuBaseInfo stuBaseInfo) {

        int sum = 0;

        //企业名称
        if (!Constant.QIYEMINGCHENG.equals(stuBaseInfo.getCorpName()))
        {
            sum++;
        }

        //统一社会信用代码
        if (!Constant.SHEHUIXINYONGDAIMA.equals(stuBaseInfo.getCreditCode()))
        {
            sum++;
        }


        //法定代表人
        if (!Constant.DAIBIAOREN.equals(stuBaseInfo.getLegalRepresent()))
        {
            sum++;
        }


        //经营状态
        if (!Constant.JINGYINGZHUANGTAI.equals(stuBaseInfo.getBussinsssState()))
        {
            sum++;
        }

        // 正确答案
        LocalDateTime localDateTime = Convert.toLocalDateTime(Constant.CHENGLIRIQI);

        LocalDateTime localDateTimeAnswer = localDateTime.plusHours(8);

        //用户输入时间
        LocalDateTime localDateTimeInput = Convert.toLocalDateTime(stuBaseInfo.getDateOfEstablish());

        //成立日期
        if (!localDateTimeAnswer.equals(localDateTimeInput))
        {
            sum++;
        }

        //行政区划
        if (!Constant.XINGZHENGQUHUA.equals(stuBaseInfo.getAdminDivision()))
        {
            sum++;
        }

        //注册资本
        if (!Constant.ZHUCEZIBEN.equals(stuBaseInfo.getRegCapital()))
        {
            sum++;
        }

        //实缴资本
        if (!Constant.SHIJIAOZIBEN.equals(stuBaseInfo.getPaidUpCapital()))
        {

            sum++;
        }

        //企业类型
        if (!Constant.QIYELEIXING.equals(stuBaseInfo.getEnterType()))
        {


            sum++;
        }

        //所属行业
        if (!Constant.SUOSHUHANGYE.equals(stuBaseInfo.getIndustry()))
        {
            sum++;
        }


        //工商注册号
        if (!Constant.GONGSHANGZHUCEHAO.equals(stuBaseInfo.getBussRegNumber()))
        {
            sum++;
        }


        //组织机构代码
        if (!Constant.ZUZHIJIGOUDAIMA.equals(stuBaseInfo.getOrgCode()))
        {
            sum++;
        }


        //纳税识别号
        if (!Constant.NASHUIRENSHIBIEHAO.equals(stuBaseInfo.getTexIdentifiNumber()))
        {
            sum++;
        }

        //纳税人资质
        if (!Constant.NASHUIRENZIZHI.equals(stuBaseInfo.getTaxQualification()))
        {
            sum++;
        }


        //营业期限
        if (!Constant.YINGYEQIXIAN.equals(stuBaseInfo.getBusinessTerm()))
        {
            sum++;
        }

        LocalDateTime localDate = Convert.toLocalDateTime(Constant.HEZHUNRIQI);
        LocalDateTime   localDateTimeAnswerDate =  localDate.plusHours(8);


        LocalDateTime localDateTimeInputDate = Convert.toLocalDateTime(stuBaseInfo.getDateOfApproval());


        //核准日期
        if (!localDateTimeAnswerDate.equals(localDateTimeInputDate))
        {
            sum++;
        }


        //等级机关
        if (!Constant.DENGJIJIGUAN.equals(stuBaseInfo.getRegAuth()))
        {
            sum++;
        }


        //参保人数
        if (!Constant.CANBAORENSHU.equals(stuBaseInfo.getNumberOfInsurePerson()))
        {
            sum++;
        }


        //注册地址
        if (!Constant.ZHUCEDIZHI.equals(stuBaseInfo.getCompanyRegAddress()))
        {
            sum++;
        }


        //经营范围
        if (!Constant.JINGYINGFANWEI.equals(stuBaseInfo.getBusinessScope()))
        {
            sum++;
        }

        //股东（第一大股东）
        if (!Constant.DIYIDAGUDONG.equals(stuBaseInfo.getShareholderName()))
        {
            sum++;
        }

        //持股比例（第一大股东）
        if (!Constant.DIYIDAGUDONGCHIGUBILI.equals(stuBaseInfo.getShareholdRatio()))
        {
            sum++;
        }

        //股东（第二大股东）
        if (!Constant.DIERDAGUDONG.equals(stuBaseInfo.getShareholderNameTwo()))
        {
            sum++;
        }

        //持股比例（第二大股东）
        if (!Constant.DIERDAGUDONGCHIGUBILI.equals(stuBaseInfo.getShareholdRatioTwo()))
        {
            sum++;
        }


        stuBaseInfo.setErrorNumber(sum);
        stuBaseInfo.setSubState(1);

        stuBaseInfo.setCaseName(Constant.ANLIMINGCHENG);
        stuBaseInfo.setCaseDetail(Constant.ANLIINFO);
        stuBaseInfo.setCreditCode(Constant.SHEHUIXINYONGDAIMA);

        return stuBaseInfo;
    }


}
