package com.sztzjy.digital_credit.service.impl;/**
 * @author 17803
 * @date 2024-04-16 16:05
 * 财务预警
 */

import cn.hutool.core.util.IdUtil;
import com.sztzjy.digital_credit.config.Constant;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.mapper.StuOperationAssetAnalysisModuleMapper;
import com.sztzjy.digital_credit.mapper.StuScoreModuleMapper;
import com.sztzjy.digital_credit.service.StuFinancialEarlyWarningService;
import com.sztzjy.digital_credit.service.StuRateService;
import com.sztzjy.digital_credit.util.ResultEntity;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class StuFinancialEarlyWarningServiceImpl implements StuFinancialEarlyWarningService {


    @Autowired
    private StuScoreModuleMapper scoreModuleMapper;

    @Autowired
    private StuOperationAssetAnalysisModuleMapper operationAssetAnalysisModuleMapper;


    @Autowired
    private StuRateService stuRateService;

    /**
        * Z计分模型
        * @param userId
        * @return
    */

    @Override
    public ResultEntity getModuleBaseInfoForZ(String userId) {

        StuScoreModuleExample scoreModuleExample = new StuScoreModuleExample();
        scoreModuleExample.createCriteria().andUserIdEqualTo(userId);

        List<StuScoreModule> scoreModuleList = scoreModuleMapper.selectByExample(scoreModuleExample);
        if (scoreModuleList.isEmpty()){
            return new ResultEntity<>(HttpStatus.OK);
        }

        return new ResultEntity(HttpStatus.OK,"查询成功！",scoreModuleList.get(0));

    }

    /**
        * Z计分模型(自动保存)
        * @param scoreModule
        * @return
    */

    @Override
    public ResultEntity moduleBaseInfoForZByAutoSave(StuScoreModule scoreModule) {

        //传过来用户未提交数据，根据提交状态进行判断，如果已经提交不修改

        StuScoreModuleExample scoreModuleExample = new StuScoreModuleExample();
        scoreModuleExample.createCriteria().andUserIdEqualTo(scoreModule.getUserId());
        List<StuScoreModule> scoreModuleList = scoreModuleMapper.selectByExample(scoreModuleExample);
        if (!scoreModuleList.isEmpty()){
            StuScoreModule info = scoreModuleList.get(0);

            //防止前端传id为null

            String id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {


                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(scoreModule,info);

            info.setId(id);
            info.setUpdateTime(new Date());


            scoreModuleMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

        //第一次保存没有用户数据


        scoreModule.setId(IdUtil.simpleUUID());
        scoreModule.setCreateTime(new Date());


        scoreModuleMapper.insertSelective(scoreModule);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");
    }

    /**
        * Z计分模型(提交算分)
        * @param scoreModule
        * @return
    */

    @Override
    public ResultEntity moduleBaseInfoForZBySubCalculate(StuScoreModule scoreModule) {

        //判断是否为第一次提交
        StuScoreModuleExample scoreModuleExample = new StuScoreModuleExample();
        scoreModuleExample.createCriteria().andUserIdEqualTo(scoreModule.getUserId());
        List<StuScoreModule> scoreModuleList = scoreModuleMapper.selectByExample(scoreModuleExample);
        if (!scoreModuleList.isEmpty()){
            //有已提交用户数据
            if (scoreModuleList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            scoreModule =   resultCheckModuleBaseInfoForZ(scoreModule);
            scoreModule.setUpdateTime(new Date());
            scoreModule.setId(scoreModuleList.get(0).getId());
            scoreModuleMapper.updateByPrimaryKeySelective(scoreModule);


            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(scoreModule,"Z计分模型",scoreModule.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",scoreModule.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            scoreModule =   resultCheckModuleBaseInfoForZ(scoreModule);
            scoreModule.setId(IdUtil.simpleUUID());
            scoreModule.setCreateTime(new Date());

            //插入数据库
            scoreModuleMapper.insertSelective(scoreModule);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(scoreModule,"Z计分模型",scoreModule.getUserId());


            return new ResultEntity<>(HttpStatus.OK,"保存成功！",scoreModule.getErrorNumber());
        }

    }

    /**
        * 营运资产分析模型全部数据
        * @param userId
        * @return
    */

    @Override
    public ResultEntity getOperationAssetAnalysisModule(String userId) {

        StuOperationAssetAnalysisModuleExample operationAssetAnalysisModuleExample = new StuOperationAssetAnalysisModuleExample();
        operationAssetAnalysisModuleExample.createCriteria().andUserIdEqualTo(userId);
        List<StuOperationAssetAnalysisModule> stuOperationAssetAnalysisModuleList = operationAssetAnalysisModuleMapper.selectByExample(operationAssetAnalysisModuleExample);
        if (!stuOperationAssetAnalysisModuleList.isEmpty()){
            return new ResultEntity<>(HttpStatus.OK,"获取成功!",stuOperationAssetAnalysisModuleList.get(0));
        }


        return new ResultEntity<>(HttpStatus.OK,"获取成功!");
    }

    /**
        * 营运资产分析模型(自动保存)
        * @param assetAnalysisModule
        * @return
    */

    @Override
    public ResultEntity operationAssetAnalysisModuleByAutoSave(StuOperationAssetAnalysisModule assetAnalysisModule) {
        //传过来用户未提交数据，根据提交状态进行判断，如果已经提交不修改

        StuOperationAssetAnalysisModuleExample analysisModuleExample = new StuOperationAssetAnalysisModuleExample();
        analysisModuleExample.createCriteria().andUserIdEqualTo(assetAnalysisModule.getUserId());
        List<StuOperationAssetAnalysisModule> scoreModuleList = operationAssetAnalysisModuleMapper.selectByExample(analysisModuleExample);
        if (!scoreModuleList.isEmpty()){
            StuOperationAssetAnalysisModule info = scoreModuleList.get(0);

            //防止前端传id为null

            String id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);
            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(assetAnalysisModule,info);

            info.setId(id);
            info.setUpdateTime(new Date());


            operationAssetAnalysisModuleMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

        //第一次保存没有用户数据


        assetAnalysisModule.setId(IdUtil.simpleUUID());
        assetAnalysisModule.setCreateTime(new Date());


        operationAssetAnalysisModuleMapper.insertSelective(assetAnalysisModule);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");
    }

    /**
        * 营运资产分析模型(提交算分)
        * @param analysisModule
        * @return
    */

    @Override
    public ResultEntity assetAnalysisModuleBySubCalculate(StuOperationAssetAnalysisModule analysisModule) {

        //判断是否为第一次提交
        StuOperationAssetAnalysisModuleExample operationAssetAnalysisModuleExample = new StuOperationAssetAnalysisModuleExample();
        operationAssetAnalysisModuleExample.createCriteria().andUserIdEqualTo(analysisModule.getUserId());
        List<StuOperationAssetAnalysisModule> moduleList = operationAssetAnalysisModuleMapper.selectByExample(operationAssetAnalysisModuleExample);
        if (!moduleList.isEmpty()){
            //有已提交用户数据
            if (moduleList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            analysisModule =   resultCheckAssetAnalysisModule(analysisModule);
            analysisModule.setUpdateTime(new Date());
            analysisModule.setId(moduleList.get(0).getId());
            operationAssetAnalysisModuleMapper.updateByPrimaryKeySelective(analysisModule);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(analysisModule,"营运资产分析模型",analysisModule.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",analysisModule.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            analysisModule =   resultCheckAssetAnalysisModule(analysisModule);
            analysisModule.setId(IdUtil.simpleUUID());
            analysisModule.setCreateTime(new Date());

            //插入数据库
            operationAssetAnalysisModuleMapper.insertSelective(analysisModule);
            //计算分数写入用户表
            stuRateService.enterScoreWriteUserByUserId(analysisModule,"营运资产分析模型",analysisModule.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",analysisModule.getErrorNumber());
        }
    }

    //营运资产分析模型(提交算分)
    private StuOperationAssetAnalysisModule resultCheckAssetAnalysisModule(StuOperationAssetAnalysisModule analysisModule) {

        int sum = 0;
        //营运资产
        if (!"-49167215.5".equals(analysisModule.getOperatAsset()))
        {
            sum ++;
        }
        //营运资本
        if (!"-1408090089".equals(analysisModule.getWorkCapital()))
        {
            sum ++;
        }
        //流动比率
        if (!"0.47".equals(analysisModule.getCurrentRatio()))
        {
            sum ++;
        }
        //速动比率
        if (!"0.28".equals(analysisModule.getQuickRatio()))
        {
            sum ++;
        }
        //短期债务净资产比率
        if (!"2.02".equals(analysisModule.getShortTermDebtToEquityRatio()))
        {
            sum ++;
        }
        //产权比率
        if (!"2.34".equals(analysisModule.getEquityRatio()))
        {
            sum ++;
        }
        //评估值
        if (!"-3.62".equals(analysisModule.getEvaluationValue()))
        {
            sum = sum + 2;
        }

        //信用限额
        if (!"0".equals(analysisModule.getEvaluationValue()))
        {
            sum = sum + 2;
        }


        analysisModule.setErrorNumber(sum);
        analysisModule.setSubState(1);

        return analysisModule;



    }


    //Z计分模型(提交算分)
    private StuScoreModule resultCheckModuleBaseInfoForZ(StuScoreModule scoreModule) {

        int sum = 0;

        //X1=营运资本/总资产
        if (! "-0.32".equals(scoreModule.getxOneFirst()))
        {
            sum = sum + 2;
        }

        //X2=营运资本/总资产
        if (! "0.05".equals(scoreModule.getxTwoFirst()))
        {
            sum = sum + 2;
        }

        //X3=营运资本/总资产
        if (! "0.07".equals(scoreModule.getxThreeFirst()))
        {
            sum = sum + 2;
        }

        //X4=营运资本/总资产
        if (! "0.15".equals(scoreModule.getxFourFirst()))
        {
            sum = sum + 2;
        }

        //X5=营运资本/总资产
        if (! "1".equals(scoreModule.getxFiveFirst()))
        {
            sum = sum + 2;
        }

        //Z值
        if (! "1".equals(scoreModule.getxFiveFirst()))
        {
            sum = sum + 2;
        }

        scoreModule.setErrorNumber(sum);

        scoreModule.setSubState(1);

        return scoreModule;




    }


}
