package com.sztzjy.digital_credit.service.impl;

import com.sztzjy.digital_credit.config.Constant;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.mapper.*;
import com.sztzjy.digital_credit.service.StuPersonalCreditReportingService;
import com.sztzjy.digital_credit.service.StuPersonalCreditService;
import com.sztzjy.digital_credit.service.StuRateService;
import com.sztzjy.digital_credit.util.BigDecimalUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;
import java.util.UUID;

/**
 * @author tz
 * @date 2024/4/15 15:16
 */
@Service
public class StuPersonalCreditServiceImpl implements StuPersonalCreditService {
    @Resource
    BigDecimalUtils bigDecimalUtils;
    @Resource
    StuUserMapper stuUserMapper;
    @Resource
    StuScoreCenterMapper stuScoreCenterMapper;
    @Resource
    TchModuleWeithMapper tchModuleWeithMapper;
    @Resource
    StuPersonalCreditReportingService stuPersonalCreditReportingService;
    @Resource
    StuRateService service;

    /**
     * 个人信息录入计分
     * @param stuPersonalInfo
     * @return
     */
    @Override
    public void personalInfoScoring(StuPersonalInfo stuPersonalInfo,String module) {
        BigDecimal scoring=new BigDecimal(0);

        if(stuPersonalInfo.getName().equals(Constant.NAME)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getGender().equals(Constant.GENDER)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getAge().equals(Constant.AGE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getIdentificationNumber().equals(Constant.IDENTIFICATION_NUMBER)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(stuPersonalInfo.getMaritalStatus().equals(Constant.MARITAL_STATUS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getEducationalBackground().equals(Constant.EDUCATIONAL_BACKGROUND)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getMailingAddress().equals(Constant.MAILING_ADDRESS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getWorkUnit().equals(Constant.WORK_UNIT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getOccupation().equals(Constant.OCCUPATION)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getIndustry().equals(Constant.INDUSTRY)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getProfessionalTitle().equals(Constant.PROFESSIONAL_TITLE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getAnnualIncomeRange().equals(Constant.ANNUAL_INCOME_RANGE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String totalAssets = stuPersonalInfo.getTotalAssets().stripTrailingZeros().toPlainString();
        if(totalAssets.equals(Constant.TOTAL_ASSETS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        String totalLiabilities = stuPersonalInfo.getTotalLiabilities().stripTrailingZeros().toPlainString();
        if(totalLiabilities.equals(Constant.TOTAL_LIABILITIES)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        String totalNetWorth = stuPersonalInfo.getTotalNetWorth().stripTrailingZeros().toPlainString();
        if(totalNetWorth.equals(Constant.TOTAL_NET_WORTH)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(stuPersonalInfo.getSpouseName().equals(Constant.SPOUSE_NAME)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getSpouseIdentificationNumber().equals(Constant.SPOUSE_IDENTIFICATION_NUMBER)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(stuPersonalInfo.getSpouseWorkUnit().equals(Constant.SPOUSE_WORK_UNIT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalInfo.getSpousePhoneNumber().equals(Constant.SPOUSE_PHONE_NUMBER)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        //成绩中心录入
        this.scoreEntry(stuPersonalInfo.getUserId(),module,scoring);
        //查询总成绩
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(stuPersonalInfo.getUserId());
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);
        if(!stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //取出总成绩
            BigDecimal trainingScore = stuScoreCenter.getTrainingScore();

            //将分数更新到user中
            StuUser stuUser = stuUserMapper.selectByPrimaryKey(stuPersonalInfo.getUserId());

            //个人征信总成绩
            stuUser.setCasePersonalCreditScore(trainingScore);
            //个人征信客观成绩
            stuUser.setCasePersonalCreditObjScore(trainingScore);


            stuUserMapper.updateByPrimaryKey(stuUser);
        }
    }

    /**
     * 信用记录--信用提示录入计分
     * @param creditReminderInfo
     */
    @Override
    public void creditReminderInfoScoring(StuPersonalCreditReminderInfo creditReminderInfo,String module) {
        BigDecimal scoring=new BigDecimal(0);
        if(creditReminderInfo.getNumberOfHousingLoans().toString().equals(Constant.NUMBER_OF_HOUSING_LOANS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(creditReminderInfo.getNumberOfOtherLoans().toString().equals(Constant.NUMBER_OF_OTHER_LOANS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(creditReminderInfo.getFirstLoanDisbursementMonth().equals(Constant.FIRST_LOAN_DISBURSEMENT_MONTH)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(creditReminderInfo.getNumberOfCreditCardAccounts().toString().equals(Constant.NUMBER_OF_CREDIT_CARD_ACCOUNTS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(creditReminderInfo.getFirstCreditCardIssuanceMonth().equals(Constant.FIRST_CREDIT_CARD_ISSUANCE_MONTH)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        //成绩中心录入
        this.scoreEntry(creditReminderInfo.getUserId(),module,scoring);
        //查询总成绩
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(creditReminderInfo.getUserId());
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);
        if(!stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //取出总成绩
            BigDecimal trainingScore = stuScoreCenter.getTrainingScore();

            //将分数更新到user中
            StuUser stuUser = stuUserMapper.selectByPrimaryKey(creditReminderInfo.getUserId());

            //个人征信总成绩
            stuUser.setCasePersonalCreditScore(trainingScore);
            //个人征信客观成绩
            stuUser.setCasePersonalCreditObjScore(trainingScore);


            stuUserMapper.updateByPrimaryKey(stuUser);
        }
    }

    @Override
    public void overdueInfoScoring(StuPersonalDefaultInfo stuPersonalDefaultInfo,String module) {
        BigDecimal scoring=new BigDecimal(0);

        if(stuPersonalDefaultInfo.getBadDebtInformationQuantity().toString().equals(Constant.BAD_DEBT_INFORMATION_QUANTITY)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String badDebtInformationBalance= stuPersonalDefaultInfo.getBadDebtInformationBalance().stripTrailingZeros().toPlainString();
        if(badDebtInformationBalance.equals(Constant.BAD_DEBT_INFORMATION_BALANCE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getAssetDisposalInformationQuantity().toString().equals(Constant.ASSET_DISPOSAL_INFORMATION_QUANTITY)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String assetDisposalInformationBalance= stuPersonalDefaultInfo.getAssetDisposalInformationBalance().stripTrailingZeros().toPlainString();
        if(assetDisposalInformationBalance.equals(Constant.ASSET_DISPOSAL_INFORMATION_BALANCE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getGuarantorCompensationInformationQuantity().toString().equals(Constant.GUARANTOR_COMPENSATION_INFORMATION_QUANTITY)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String guarantorCompensationInformationBalance= stuPersonalDefaultInfo.getGuarantorCompensationInformationBalance().stripTrailingZeros().toPlainString();
        if(guarantorCompensationInformationBalance.equals(Constant.GUARANTOR_COMPENSATION_INFORMATION_BALANCE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getOverdueQuantity().toString().equals(Constant.OVERDUE_QUANTITY)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getOverdueNumberOfMonths().toString().equals(Constant.OVERDUE_NUMBER_OF_MONTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String overdueMaximumOverdueTotalAmountSingleMonth= stuPersonalDefaultInfo.getOverdueMaximumOverdueTotalAmountSingleMonth().stripTrailingZeros().toPlainString();
        if(overdueMaximumOverdueTotalAmountSingleMonth.equals(Constant.OVERDUE_MAXIMUM_OVERDUE_TOTAL_AMOUNT_SINGLE_MONTH)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getOverdueMaximumOverdueMonths().toString().equals(Constant.OVERDUE_MAXIMUM_OVERDUE_MONTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getCreditCardOverdueNumberOfAccounts().toString().equals(Constant.CREDIT_CARD_OVERDUE_NUMBER_OF_ACCOUNTS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getCreditCardOverdueNumberOfMonths().toString().equals(Constant.CREDIT_CARD_OVERDUE_NUMBER_OF_MONTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String amountSingleMonth = stuPersonalDefaultInfo.getCreditCardOverdueMaximumOverdueTotalAmountSingleMonth().stripTrailingZeros().toPlainString();
        if(amountSingleMonth.equals(Constant.CREDIT_CARD_OVERDUE_MAXIMUM_OVERDUE_TOTAL_AMOUNT_SINGLE_MONTH)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalDefaultInfo.getCreditCardOverdueMaximumOverdueMonths().toString().equals(Constant.CREDIT_CARD_OVERDUE_MAXIMUM_OVERDUE_MONTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }
        //成绩中心录入
        this.scoreEntry(stuPersonalDefaultInfo.getUserId(),module,scoring);
        //查询总成绩
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(stuPersonalDefaultInfo.getUserId());
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);
        if(!stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //取出总成绩
            BigDecimal trainingScore = stuScoreCenter.getTrainingScore();

            //将分数更新到user中
            StuUser stuUser = stuUserMapper.selectByPrimaryKey(stuPersonalDefaultInfo.getUserId());

            //个人征信总成绩
            stuUser.setCasePersonalCreditScore(trainingScore);
            //个人征信客观成绩
            stuUser.setCasePersonalCreditObjScore(trainingScore);


            stuUserMapper.updateByPrimaryKey(stuUser);
        }
    }

    @Override
    public void creditGrantingScoring(StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo,String module) {
        BigDecimal scoring=new BigDecimal(0);

        if(stuPersonalOutstandingLoansInfo.getNumberOfLoanInstitutions().toString().equals(Constant.NUMBER_OF_LOAN_INSTITUTIONS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalOutstandingLoansInfo.getNumberOfTransactions().toString().equals(Constant.NUMBER_OF_TRANSACTIONS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }
        String totalContractAmount = stuPersonalOutstandingLoansInfo.getTotalContractAmount().stripTrailingZeros().toString();
        if(totalContractAmount.equals(Constant.TOTAL_CONTRACT_AMOUNT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        String balance= stuPersonalOutstandingLoansInfo.getBalance().stripTrailingZeros().toPlainString();
        if(balance.equals(Constant.BALANCE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        String dueRecentlySixMonths= stuPersonalOutstandingLoansInfo.getAverageRepaymentDueRecentlySixMonths().stripTrailingZeros().toPlainString();
        if(dueRecentlySixMonths.equals(Constant.AVERAGE_REPAYMENT_DUE_RECENTLY_SIX_MONTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        if(stuPersonalOutstandingLoansInfo.getCreditCardNumberOfIssuingInstitutions().toString().equals(Constant.CREDIT_CARD_NUMBER_OF_ISSUING_INSTITUTIONS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalOutstandingLoansInfo.getCreditCardNumberOfAccounts().toString().equals(Constant.CREDIT_CARD_NUMBER_OF_ACCOUNTS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String creditCardTotalCreditAmount= stuPersonalOutstandingLoansInfo.getCreditCardTotalCreditAmount().stripTrailingZeros().toPlainString();
        if(creditCardTotalCreditAmount.equals(Constant.CREDIT_CARD_TOTAL_CREDIT_AMOUNT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String maximumCreditLimitBank= stuPersonalOutstandingLoansInfo.getCreditCardMaximumCreditLimitBank().stripTrailingZeros().toPlainString();
        if(maximumCreditLimitBank.equals(Constant.CREDIT_CARD_MAXIMUM_CREDIT_LIMIT_BANK)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String minimumCreditLimitBank= stuPersonalOutstandingLoansInfo.getCreditCardMinimumCreditLimitBank().stripTrailingZeros().toPlainString();
        if(minimumCreditLimitBank.equals(Constant.CREDIT_CARD_MINIMUM_CREDIT_LIMIT_BANK)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String creditCardUsedCreditLimit= stuPersonalOutstandingLoansInfo.getCreditCardUsedCreditLimit().stripTrailingZeros().toPlainString();
        if(creditCardUsedCreditLimit.equals(Constant.CREDIT_CARD_USED_CREDIT_LIMIT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String CreditCardSixMonthsths= stuPersonalOutstandingLoansInfo.getCreditCardSixMonthsths().stripTrailingZeros().toPlainString();
        if(CreditCardSixMonthsths.equals(Constant.CREDIT_CARD_SIX_MONTHSTHS)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        if(stuPersonalOutstandingLoansInfo.getGuaranteeNumberOfGuarantees().toString().equals(Constant.GUARANTEE_NUMBER_OF_GUARANTEES)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }

        String guaranteeAmount = stuPersonalOutstandingLoansInfo.getGuaranteeAmount().stripTrailingZeros().toPlainString();
        if(guaranteeAmount.equals(Constant.GUARANTEE_AMOUNT)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        String guaranteedPrincipalBalance = stuPersonalOutstandingLoansInfo.getGuaranteedPrincipalBalance().stripTrailingZeros().toPlainString();
        if(guaranteedPrincipalBalance.equals(Constant.GUARANTEED_PRINCIPAL_BALANCE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //成绩中心录入
        this.scoreEntry(stuPersonalOutstandingLoansInfo.getUserId(),module,scoring);
        //查询总成绩
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(stuPersonalOutstandingLoansInfo.getUserId());
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);
        if(!stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //取出总成绩
            BigDecimal trainingScore = stuScoreCenter.getTrainingScore();

            //将分数更新到user中
            StuUser stuUser = stuUserMapper.selectByPrimaryKey(stuPersonalOutstandingLoansInfo.getUserId());

            //个人征信总成绩
            stuUser.setCasePersonalCreditScore(trainingScore);
            //个人征信客观成绩
            stuUser.setCasePersonalCreditObjScore(trainingScore);


            stuUserMapper.updateByPrimaryKey(stuUser);
        }
    }

    @Override
    public void creditScoreScoring(StuCreditScore stuCreditScore,String module) {
        BigDecimal scoring=new BigDecimal(0);
        //自然情况得分情况
        if(stuCreditScore.getAgeScore().equals(Constant.AGE_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }
        if(stuCreditScore.getGenderScore().equals(Constant.GENDER_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getMaritalStatusScore().equals(Constant.MARITAL_STATUS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getEducationalLevelScore().equals(Constant.EDUCATIONAL_LEVEL_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getDrivingExperienceScore().equals(Constant.DRIVING_EXPERIENCE_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getHealthConditionScore().equals(Constant.HEALTH_CONDITION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getResidenceTimeScore().equals(Constant.RESIDENCE_TIME_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //职业情况得分情况
        if(stuCreditScore.getOccupationScore().equals(Constant.OCCUPATION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getYearsInCurrentCompanyScore().equals(Constant.YEARS_IN_CURRENT_COMPANY_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getPostScore().equals(Constant.POST_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getTechnicalTitleScore().equals(Constant.TECHNICAL_TITLE_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getPersonalAnnualIncomeScore().equals(Constant.PERSONAL_ANNUAL_INCOME_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //保障支持得分情况
        if(stuCreditScore.getHousingSituationScore().equals(Constant.HOUSING_SITUATION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getNetAssetSituationScore().equals(Constant.NET_ASSET_SITUATION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getVehicleConditionScore().equals(Constant.VEHICLE_CONDITION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getMonthlyIncomeScore().equals(Constant.MONTHLY_INCOME_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getMonthlyFixedScore().equals(Constant.MONTHLY_FIXED_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getDebtToIncomeRatio().equals(Constant.DEBT_TO_INCOME_RATIO)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }
        if(stuCreditScore.getNumberOfDependentsScore().equals(Constant.NUMBER_OF_DEPENDENTS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //与银行关系得分情况
        if(stuCreditScore.getLoanHistoryScore().equals(Constant.LOAN_HISTORY_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getCardholderStatusScore().equals(Constant.CARDHOLDER_STATUS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //调整项得分情况
        if(stuCreditScore.getCreditHistoryScore().equals(Constant.CREDIT_HISTORY_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getPersonalBadReputationScore().equals(Constant.PERSONAL_BAD_REPUTATION_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getPersonalMisconductOrRecordsScore().equals(Constant.PERSONAL_MISCONDUCT_OR_RECORDS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getTaxArrearsRecordsScore().equals(Constant.TAX_ARREARS_RECORDS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getCivilJudgmentOrEnforcementScore().equals(Constant.CIVIL_JUDGMENT_OR_ENFORCEMENT_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getSocialSecurityAndProvidentFundPaymentScore().equals(Constant.SOCIAL_SECURITY_AND_PROVIDENT_FUND_PAYMENT_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(2));
        }
        if(stuCreditScore.getPublicUtilityPaymentRecordsScore().equals(Constant.PUBLIC_UTILITY_PAYMENT_RECORDS_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getPracticeQualificationCertificateScore().equals(Constant.PRACTICE_QUALIFICATION_CERTIFICATE_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }
        if(stuCreditScore.getAdministrativeRewardScore().equals(Constant.ADMINISTRATIVE_REWARD_SCORE)){
            scoring=bigDecimalUtils.add(scoring.toString(),String.valueOf(1));
        }

        //成绩中心录入
        this.scoreEntry(stuCreditScore.getUserId(),module,scoring);
        //查询总成绩
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(stuCreditScore.getUserId());
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);
        if(!stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //取出总成绩
            BigDecimal trainingScore = stuScoreCenter.getTrainingScore();

            //将分数更新到user中
            StuUser stuUser = stuUserMapper.selectByPrimaryKey(stuCreditScore.getUserId());

            //个人征信总成绩
            stuUser.setCasePersonalCreditScore(trainingScore);
            //个人征信客观成绩
            stuUser.setCasePersonalCreditObjScore(trainingScore);


            stuUserMapper.updateByPrimaryKey(stuUser);
        }
    }


    /**
     * 成绩中心录入案例考核成绩
     * @param userId
     */
    public void scoreEntry(String userId,String module,BigDecimal score){
        // TODO: 2024/4/24 判断用户第几次实训 重新实训次数（0：第一次 1：第二次 2：第三次）
        StuScoreCenterExample scoreCenterExample=new StuScoreCenterExample();
        scoreCenterExample.createCriteria().andUserIdEqualTo(userId);
        List<StuScoreCenter> stuScoreCenters = stuScoreCenterMapper.selectByExample(scoreCenterExample);


        //查询权重
        StuUser stuUser = stuUserMapper.selectByPrimaryKey(userId);
        TchModuleWeithExample example=new TchModuleWeithExample();
        example.createCriteria().andSchoolIdEqualTo(stuUser.getSchoolId());
        List<TchModuleWeith> tchModuleWeiths = tchModuleWeithMapper.selectByExample(example);

        if(tchModuleWeiths.isEmpty()){
            TchModuleWeith tchModuleWeith=new TchModuleWeith(stuUser.getSchoolId());
            tchModuleWeithMapper.insert(tchModuleWeith);
            tchModuleWeiths.add(tchModuleWeith);
        }

        TchModuleWeith tchModuleWeith = tchModuleWeiths.get(0);


        if(stuScoreCenters.isEmpty()){
            StuScoreCenter stuScoreCenter=new StuScoreCenter();
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuScoreCenter.setId(uuid);
            stuScoreCenter.setLearningProjects(module);
            stuScoreCenter.setTrainingTotalScore(BigDecimal.valueOf(100));


            //设置权重和完成情况
            Boolean schedule;
            if(module.equals(Constant.PERSONAL_CREDIT)){
                stuScoreCenter.setScoreWeight(tchModuleWeith.getCasePersonalCreditWeith()); //个人征信--权重
                schedule= stuPersonalCreditReportingService.getSchedule(userId); //个人征信--完成情况
            }else {
                stuScoreCenter.setScoreWeight(tchModuleWeith.getCaseCorporateCreditWeith()); //企业征信--权重
                schedule=service.completionStatusOfEnterprise(userId); //企业征信--完成情况
            }

            //完成情况
            if(schedule){
                stuScoreCenter.setCompletionStatus("已完成");
            }else {
                stuScoreCenter.setCompletionStatus("未完成");
            }

            //设置得分信息
            stuScoreCenter.setTrainingScore(score);
            stuScoreCenter.setTrainingScoreOne(score);

            stuScoreCenter.setUserId(userId);
            stuScoreCenter.setModule(module);
            stuScoreCenter.setAscription(Constant.COMPREHENSIVE_CASE);
            stuScoreCenter.setNumberOfTraining(0);

            stuScoreCenterMapper.insert(stuScoreCenter);
        }else {
            StuScoreCenter stuScoreCenter = stuScoreCenters.get(0);
            //更新权重
            if(module.equals(Constant.PERSONAL_CREDIT)){
                stuScoreCenter.setScoreWeight(tchModuleWeith.getCasePersonalCreditWeith());
            }else {
                stuScoreCenter.setScoreWeight(tchModuleWeith.getCaseCorporateCreditWeith());
            }
            //判断是第几次实训
            if(stuScoreCenter.getNumberOfTraining()==0){ //第一次实训
                //累加分数
                //第一次提交成绩
                stuScoreCenter.setTrainingScoreOne(bigDecimalUtils.add(stuScoreCenter.getTrainingScoreOne().toString(),score.toString()));
                //总成绩
                stuScoreCenter.setTrainingScore(bigDecimalUtils.add(stuScoreCenter.getTrainingScore().toString(),score.toString()));
            }

            if(stuScoreCenter.getNumberOfTraining()==1){ //第二次实训
                //累加分数
                //第二次提交成绩
                stuScoreCenter.setTrainingScoreTwo(bigDecimalUtils.add(stuScoreCenter.getTrainingScoreTwo().toString(),score.toString()));
                //计算平均分
                BigDecimal add = bigDecimalUtils.add(stuScoreCenter.getTrainingScoreOne().toString(), stuScoreCenter.getTrainingScoreTwo().toString());
                String div = bigDecimalUtils.div(add.toString(), String.valueOf(2), 2);
                //总成绩
                stuScoreCenter.setTrainingScore(new BigDecimal(div));
            }

            if(stuScoreCenter.getNumberOfTraining()==2){ //第三次实训
                //累加分数
                //第三次提交成绩
                stuScoreCenter.setTrainingScoreThree(bigDecimalUtils.add(stuScoreCenter.getTrainingScoreThree().toString(),score.toString()));
                //计算平均分
                BigDecimal add = bigDecimalUtils.add(stuScoreCenter.getTrainingScoreOne().toString(), stuScoreCenter.getTrainingScoreTwo().toString());
                BigDecimal add1 = bigDecimalUtils.add(add.toString(), stuScoreCenter.getTrainingScoreThree().toString());
                String div = bigDecimalUtils.div(add1.toString(), String.valueOf(3), 2);
                //总成绩
                stuScoreCenter.setTrainingScore(new BigDecimal(div));
            }

            //更新完成情况
            boolean schedule = stuPersonalCreditReportingService.getSchedule(userId);
            if(schedule){
                stuScoreCenter.setCompletionStatus("已完成");
            }else {
                stuScoreCenter.setCompletionStatus("未完成");
            }

            stuScoreCenterMapper.updateByPrimaryKey(stuScoreCenter);
        }
    }
}
