package com.sztzjy.digital_credit.service.impl;

import com.itextpdf.text.pdf.parser.PathConstructionRenderInfo;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.mapper.*;
import com.sztzjy.digital_credit.service.StuPersonalCreditReportingService;
import com.sztzjy.digital_credit.service.StuPersonalCreditService;
import org.springframework.beans.BeanUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.core.parameters.P;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * @author tz
 * @date 2024/4/15 10:42
 */
@Service
public class StuPersonalInfoEntryServiceImpl implements StuPersonalCreditReportingService {
    @Resource
    StuPersonalInfoMapper stuPersonalInfoMapper;
    @Lazy
    @Resource
    StuPersonalCreditService stuPersonalCreditService;
    @Resource
    StuPersonalCreditReminderInfoMapper stuPersonalCreditReminderInfoMapper;
    @Resource
    StuPersonalDefaultInfoMapper stuPersonalDefaultInfoMapper;
    @Resource
    StuPersonalOutstandingLoansInfoMapper stuPersonalOutstandingLoansInfoMapper;
    @Resource
    StuCreditScoreMapper stuCreditScoreMapper;
    @Resource
    StuCreditEnhanceMeasureMapper stuCreditEnhanceMeasureMapper;
    @Override
    public StuPersonalInfo getPersonalInfo(String userId) {
        StuPersonalInfoExample example=new StuPersonalInfoExample();
        example.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalInfo> stuPersonalInfos = stuPersonalInfoMapper.selectByExample(example);
        if (!stuPersonalInfos.isEmpty()){
            return stuPersonalInfos.get(0);
        }
        return null;
    }

    @Override
    public void servePersonalInfo(StuPersonalInfo stuPersonalInfo) {
        StuPersonalInfoExample example=new StuPersonalInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalInfo.getUserId());
        List<StuPersonalInfo> stuPersonalInfos = stuPersonalInfoMapper.selectByExample(example);

        //三种情况 1、用户未保存过信息：直接添加 2、用户已保存过信息，但未提交：更新全部信息 3、用户已保存过信息，也已提交：不做任何修改
        // TODO: 2024/4/15 1、用户未保存过信息：直接添加
        if(stuPersonalInfos.isEmpty()){
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalInfo.setId(uuid);
            stuPersonalInfo.setCreationTime(new Date());
            stuPersonalInfoMapper.insert(stuPersonalInfo);
        }else {
            StuPersonalInfo personalInfo = stuPersonalInfos.get(0);
            Integer id = personalInfo.getId();
            if(personalInfo.getSubmitStatus()==0){
                // TODO: 2024/4/15 2、用户已保存过信息，但未提交：更新全部信息
                BeanUtils.copyProperties(stuPersonalInfo,personalInfo);
                personalInfo.setUpdateTime(new Date());
                personalInfo.setId(id);
                stuPersonalInfoMapper.updateByPrimaryKey(personalInfo);
            }else {
                // TODO: 2024/4/15 3、用户已保存过信息，也已提交：不做任何修改
            }
        }
    }

    @Override
    public void submitPersonalInfo(StuPersonalInfo stuPersonalInfo,String module) {
        StuPersonalInfoExample example=new StuPersonalInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalInfo.getUserId());
        List<StuPersonalInfo> stuPersonalInfos = stuPersonalInfoMapper.selectByExample(example);
        //判断用户是否已提交
        if(!stuPersonalInfos.isEmpty()){
            StuPersonalInfo personalInfo = stuPersonalInfos.get(0);
            Integer id = personalInfo.getId();

            if(personalInfo.getSubmitStatus()==1){
                // TODO: 2024/4/15 用户已提交不做任何更新
                return;
            }else {
                // TODO: 2024/4/15 自动保存并给用户计分并更新提交状态
                BeanUtils.copyProperties(stuPersonalInfo,personalInfo);
                personalInfo.setUpdateTime(new Date());
                personalInfo.setId(id);
                personalInfo.setSubmitStatus(1);
                stuPersonalInfoMapper.updateByPrimaryKey(personalInfo);
            }
        }else {
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalInfo.setId(uuid);
            stuPersonalInfo.setCreationTime(new Date());
            stuPersonalInfoMapper.insert(stuPersonalInfo);
        }
        //计分
        stuPersonalCreditService.personalInfoScoring(stuPersonalInfo,module);
    }

    @Override
    public StuPersonalCreditReminderInfo getCreditReminder(String userId) {
        StuPersonalCreditReminderInfoExample example=new StuPersonalCreditReminderInfoExample();
        example.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalCreditReminderInfo> stuPersonalCreditReminderInfos = stuPersonalCreditReminderInfoMapper.selectByExample(example);
        if(!stuPersonalCreditReminderInfos.isEmpty()){
            return stuPersonalCreditReminderInfos.get(0);
        }
        return null;
    }

    @Override
    public void serveCreditReminder(StuPersonalCreditReminderInfo creditReminderInfo) {
        StuPersonalCreditReminderInfoExample example=new StuPersonalCreditReminderInfoExample();
        example.createCriteria().andUserIdEqualTo(creditReminderInfo.getUserId());
        List<StuPersonalCreditReminderInfo> stuPersonalCreditReminderInfos = stuPersonalCreditReminderInfoMapper.selectByExample(example);

        //三种情况 1、用户未保存过信息：直接添加 2、用户已保存过信息，但未提交：更新全部信息 3、用户已保存过信息，也已提交：不做任何修改
        // TODO: 2024/4/15 1、用户未保存过信息：直接添加
        if(stuPersonalCreditReminderInfos.isEmpty()){
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            creditReminderInfo.setId(uuid);
            creditReminderInfo.setCreationTime(new Date());
            stuPersonalCreditReminderInfoMapper.insert(creditReminderInfo);
        }else {
            StuPersonalCreditReminderInfo reminderInfo = stuPersonalCreditReminderInfos.get(0);
            Integer id = reminderInfo.getId();
            if(reminderInfo.getSubmitStatus()==0){
                // TODO: 2024/4/15 2、用户已保存过信息，但未提交：更新全部信息
                BeanUtils.copyProperties(creditReminderInfo,reminderInfo);
                reminderInfo.setId(id);
                reminderInfo.setUpdateTime(new Date());
                stuPersonalCreditReminderInfoMapper.updateByPrimaryKey(reminderInfo);
            }else {
                // TODO: 2024/4/15 3、用户已保存过信息，也已提交：不做任何修改
            }
        }
    }

    @Override
    public void submitCreditReminder(StuPersonalCreditReminderInfo creditReminderInfo,String module) {
        StuPersonalCreditReminderInfoExample example=new StuPersonalCreditReminderInfoExample();
        example.createCriteria().andUserIdEqualTo(creditReminderInfo.getUserId());
        List<StuPersonalCreditReminderInfo> stuPersonalCreditReminderInfos = stuPersonalCreditReminderInfoMapper.selectByExample(example);
        //判断用户是否已提交
        if(!stuPersonalCreditReminderInfos.isEmpty()){
            StuPersonalCreditReminderInfo reminderInfo = stuPersonalCreditReminderInfos.get(0);
            Integer id = reminderInfo.getId();
            if(reminderInfo.getSubmitStatus()==1){
                // TODO: 2024/4/15 用户已提交不做任何更新
                return;
            }else {
                // TODO: 2024/4/15 更新数据或自动保存并给用户计分并更新提交状态
                BeanUtils.copyProperties(creditReminderInfo,reminderInfo);
                reminderInfo.setId(id);
                reminderInfo.setUpdateTime(new Date());
                reminderInfo.setSubmitStatus(1);
                stuPersonalCreditReminderInfoMapper.updateByPrimaryKey(reminderInfo);
            }
        }else {
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            creditReminderInfo.setId(uuid);
            creditReminderInfo.setCreationTime(new Date());
            stuPersonalCreditReminderInfoMapper.insert(creditReminderInfo);
        }
        //计分
        stuPersonalCreditService.creditReminderInfoScoring(creditReminderInfo,module);
    }

    @Override
    public StuPersonalDefaultInfo getOverdueInfo(String userId) {
        StuPersonalDefaultInfoExample example=new StuPersonalDefaultInfoExample();
        example.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalDefaultInfo> stuPersonalDefaultInfos = stuPersonalDefaultInfoMapper.selectByExample(example);
        if(!stuPersonalDefaultInfos.isEmpty()){
            return stuPersonalDefaultInfos.get(0);
        }
        return null;
    }

    @Override
    public void serveOverdueInfo(StuPersonalDefaultInfo stuPersonalDefaultInfo) {
        StuPersonalDefaultInfoExample example=new StuPersonalDefaultInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalDefaultInfo.getUserId());
        List<StuPersonalDefaultInfo> stuPersonalDefaultInfos = stuPersonalDefaultInfoMapper.selectByExample(example);

        //三种情况 1、用户未保存过信息：直接添加 2、用户已保存过信息，但未提交：更新全部信息 3、用户已保存过信息，也已提交：不做任何修改
        // TODO: 2024/4/15 1、用户未保存过信息：直接添加
        if(stuPersonalDefaultInfos.isEmpty()){
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalDefaultInfo.setId(uuid);
            stuPersonalDefaultInfo.setCreationTime(new Date());
            stuPersonalDefaultInfoMapper.insert(stuPersonalDefaultInfo);
        }else {
            StuPersonalDefaultInfo personalDefaultInfo = stuPersonalDefaultInfos.get(0);
            Integer id = personalDefaultInfo.getId();
            if(personalDefaultInfo.getSubmitStatus()==0){
                // TODO: 2024/4/15 2、用户已保存过信息，但未提交：更新全部信息
                BeanUtils.copyProperties(stuPersonalDefaultInfo,personalDefaultInfo);
                personalDefaultInfo.setId(id);
                personalDefaultInfo.setUpdateTime(new Date());
                stuPersonalDefaultInfoMapper.updateByPrimaryKey(personalDefaultInfo);
            }else {
                // TODO: 2024/4/15 3、用户已保存过信息，也已提交：不做任何修改
            }
        }
    }

    @Override
    public void submitOverdueInfo(StuPersonalDefaultInfo stuPersonalDefaultInfo,String module) {
        StuPersonalDefaultInfoExample example=new StuPersonalDefaultInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalDefaultInfo.getUserId());
        List<StuPersonalDefaultInfo> stuPersonalDefaultInfos = stuPersonalDefaultInfoMapper.selectByExample(example);
        //判断用户是否已提交
        if(!stuPersonalDefaultInfos.isEmpty()){
            StuPersonalDefaultInfo personalDefaultInfo = stuPersonalDefaultInfos.get(0);
            Integer id = personalDefaultInfo.getId();
            if(personalDefaultInfo.getSubmitStatus()==1){
                // TODO: 2024/4/15 用户已提交不做任何更新
                return;
            }else {
                // TODO: 2024/4/15 更新数据或自动保存并给用户计分并更新提交状态
                BeanUtils.copyProperties(stuPersonalDefaultInfo,personalDefaultInfo);
                personalDefaultInfo.setId(id);
                personalDefaultInfo.setUpdateTime(new Date());
                personalDefaultInfo.setSubmitStatus(1);
                stuPersonalDefaultInfoMapper.updateByPrimaryKey(personalDefaultInfo);
            }
        }else {
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalDefaultInfo.setId(uuid);
            stuPersonalDefaultInfo.setCreationTime(new Date());
            stuPersonalDefaultInfoMapper.insert(stuPersonalDefaultInfo);
        }
        //计分
        stuPersonalCreditService.overdueInfoScoring(stuPersonalDefaultInfo,module);
    }

    @Override
    public StuPersonalOutstandingLoansInfo getCreditGranting(String userId) {
        StuPersonalOutstandingLoansInfoExample example=new StuPersonalOutstandingLoansInfoExample();
        example.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalOutstandingLoansInfo> stuPersonalOutstandingLoansInfos = stuPersonalOutstandingLoansInfoMapper.selectByExample(example);
        if(!stuPersonalOutstandingLoansInfos.isEmpty()){
            return stuPersonalOutstandingLoansInfos.get(0);
        }
        return null;
    }

    @Override
    public void serveCreditGranting(StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo) {
        StuPersonalOutstandingLoansInfoExample example=new StuPersonalOutstandingLoansInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalOutstandingLoansInfo.getUserId());
        List<StuPersonalOutstandingLoansInfo> stuPersonalOutstandingLoansInfos = stuPersonalOutstandingLoansInfoMapper.selectByExample(example);

        //三种情况 1、用户未保存过信息：直接添加 2、用户已保存过信息，但未提交：更新全部信息 3、用户已保存过信息，也已提交：不做任何修改
        // TODO: 2024/4/15 1、用户未保存过信息：直接添加
        if(stuPersonalOutstandingLoansInfos.isEmpty()){
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalOutstandingLoansInfo.setId(uuid);
            stuPersonalOutstandingLoansInfo.setCreationTime(new Date());
            stuPersonalOutstandingLoansInfoMapper.insert(stuPersonalOutstandingLoansInfo);
        }else {
            StuPersonalOutstandingLoansInfo personalOutstandingLoansInfo = stuPersonalOutstandingLoansInfos.get(0);
            Integer id = personalOutstandingLoansInfo.getId();
            if(personalOutstandingLoansInfo.getSubmitStatus()==0){
                // TODO: 2024/4/15 2、用户已保存过信息，但未提交：更新全部信息
                BeanUtils.copyProperties(stuPersonalOutstandingLoansInfo,personalOutstandingLoansInfo);
                personalOutstandingLoansInfo.setId(id);
                personalOutstandingLoansInfo.setUpdateTime(new Date());
                stuPersonalOutstandingLoansInfoMapper.updateByPrimaryKey(personalOutstandingLoansInfo);
            }else {
                // TODO: 2024/4/15 3、用户已保存过信息，也已提交：不做任何修改
            }
        }
    }

    @Override
    public void submitCreditGranting(StuPersonalOutstandingLoansInfo stuPersonalOutstandingLoansInfo,String module) {
        StuPersonalOutstandingLoansInfoExample example=new StuPersonalOutstandingLoansInfoExample();
        example.createCriteria().andUserIdEqualTo(stuPersonalOutstandingLoansInfo.getUserId());
        List<StuPersonalOutstandingLoansInfo> stuPersonalOutstandingLoansInfos = stuPersonalOutstandingLoansInfoMapper.selectByExample(example);
        //判断用户是否已提交
        if(!stuPersonalOutstandingLoansInfos.isEmpty()){
            StuPersonalOutstandingLoansInfo personalOutstandingLoansInfo = stuPersonalOutstandingLoansInfos.get(0);
            Integer id = personalOutstandingLoansInfo.getId();
            if(personalOutstandingLoansInfo.getSubmitStatus()==1){
                // TODO: 2024/4/15 用户已提交不做任何更新
                return;
            }else {
                // TODO: 2024/4/15 更新数据或自动保存并给用户计分并更新提交状态
                BeanUtils.copyProperties(stuPersonalOutstandingLoansInfo,personalOutstandingLoansInfo);
                personalOutstandingLoansInfo.setId(id);
                personalOutstandingLoansInfo.setUpdateTime(new Date());
                personalOutstandingLoansInfo.setSubmitStatus(1);
                stuPersonalOutstandingLoansInfoMapper.updateByPrimaryKey(personalOutstandingLoansInfo);
            }
        }else {
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuPersonalOutstandingLoansInfo.setId(uuid);
            stuPersonalOutstandingLoansInfo.setCreationTime(new Date());
            stuPersonalOutstandingLoansInfoMapper.insert(stuPersonalOutstandingLoansInfo);
        }
        //计分
        stuPersonalCreditService.creditGrantingScoring(stuPersonalOutstandingLoansInfo,module);
    }

    @Override
    public StuCreditScore getCreditScore(String userId) {
        StuCreditScoreExample example=new StuCreditScoreExample();
        example.createCriteria().andUserIdEqualTo(userId);
        List<StuCreditScore> stuCreditScores = stuCreditScoreMapper.selectByExample(example);
        if(!stuCreditScores.isEmpty()){
            return stuCreditScores.get(0);
        }
        return null;
    }

    @Override
    public void serveCreditScore(StuCreditScore stuCreditScore) {
        StuCreditScoreExample example=new StuCreditScoreExample();
        example.createCriteria().andUserIdEqualTo(stuCreditScore.getUserId());
        List<StuCreditScore> stuCreditScores = stuCreditScoreMapper.selectByExample(example);

        //三种情况 1、用户未保存过信息：直接添加 2、用户已保存过信息，但未提交：更新全部信息 3、用户已保存过信息，也已提交：不做任何修改
        // TODO: 2024/4/15 1、用户未保存过信息：直接添加
        if(stuCreditScores.isEmpty()){
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuCreditScore.setId(uuid);
            stuCreditScore.setCreationTime(new Date());
            stuCreditScoreMapper.insert(stuCreditScore);
        }else {
            StuCreditScore creditScore = stuCreditScores.get(0);
            Integer id = creditScore.getId();
            if(creditScore.getSubmitStatus()==0){
                // TODO: 2024/4/15 2、用户已保存过信息，但未提交：更新全部信息
                BeanUtils.copyProperties(stuCreditScore,creditScore);
                creditScore.setId(id);
                creditScore.setUpdateTime(new Date());
                stuCreditScoreMapper.updateByPrimaryKey(creditScore);
            }else {
                // TODO: 2024/4/15 3、用户已保存过信息，也已提交：不做任何修改
            }
        }
    }

    @Override
    public void submitCreditScore(StuCreditScore stuCreditScore,String module) {
        StuCreditScoreExample example=new StuCreditScoreExample();
        example.createCriteria().andUserIdEqualTo(stuCreditScore.getUserId());
        List<StuCreditScore> stuCreditScores = stuCreditScoreMapper.selectByExample(example);
        //判断用户是否已提交
        if(!stuCreditScores.isEmpty()){
            StuCreditScore creditScore = stuCreditScores.get(0);
            Integer id = creditScore.getId();
            if(creditScore.getSubmitStatus()==1){
                // TODO: 2024/4/15 用户已提交不做任何更新
                return;
            }else {
                // TODO: 2024/4/15 更新数据或自动保存并给用户计分并更新提交状态
                BeanUtils.copyProperties(stuCreditScore,creditScore);
                creditScore.setId(id);
                creditScore.setUpdateTime(new Date());
                creditScore.setSubmitStatus(1);
                stuCreditScoreMapper.updateByPrimaryKey(creditScore);
            }
        }else {
            Integer uuid = UUID.randomUUID().toString().replaceAll("-", "").hashCode();
            uuid = uuid < 0 ? -uuid : uuid;//String.hashCode() 值会为空
            stuCreditScore.setId(uuid);
            stuCreditScore.setCreationTime(new Date());
            stuCreditScoreMapper.insert(stuCreditScore);
        }
        //计分
        stuPersonalCreditService.creditScoreScoring(stuCreditScore,module);
    }

    @Override
    public void againTraining(String userId) {

    }


    /**
     * 个人征信完成进度
     * @return
     */
    public boolean getSchedule(String userId){
        //查询个人信息录入是否提交
        StuPersonalInfoExample personalInfoExample=new StuPersonalInfoExample();
        personalInfoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalInfo> stuPersonalInfos = stuPersonalInfoMapper.selectByExample(personalInfoExample);
        if(stuPersonalInfos.isEmpty()){
            return false;
        }else {
            if(stuPersonalInfos.get(0).getSubmitStatus()!=1){
                return false;
            }
        }

        //查询信用记录--信用提示是否提交
        StuPersonalCreditReminderInfoExample reminderInfoExample=new StuPersonalCreditReminderInfoExample();
        reminderInfoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalCreditReminderInfo> stuPersonalCreditReminderInfos = stuPersonalCreditReminderInfoMapper.selectByExample(reminderInfoExample);
        if(stuPersonalCreditReminderInfos.isEmpty()){
            return false;
        }else {
            if(stuPersonalCreditReminderInfos.get(0).getSubmitStatus()!=1){
                return false;
            }
        }

        //查询信用记录-逾期及违约信息概要是否提交
        StuPersonalDefaultInfoExample defaultInfoExample=new StuPersonalDefaultInfoExample();
        defaultInfoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalDefaultInfo> stuPersonalDefaultInfos = stuPersonalDefaultInfoMapper.selectByExample(defaultInfoExample);
        if(stuPersonalDefaultInfos.isEmpty()){
            return false;
        }else {
            if(stuPersonalDefaultInfos.get(0).getSubmitStatus()!=1){
                return false;
            }
        }

        //查询信用记录-授信及负债信息概要是否提交
        StuPersonalOutstandingLoansInfoExample loansInfoExample=new StuPersonalOutstandingLoansInfoExample();
        loansInfoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuPersonalOutstandingLoansInfo> stuPersonalOutstandingLoansInfos = stuPersonalOutstandingLoansInfoMapper.selectByExample(loansInfoExample);
        if(stuPersonalOutstandingLoansInfos.isEmpty()){
            return false;
        }else {
            if(stuPersonalDefaultInfos.get(0).getSubmitStatus()!=1){
                return false;
            }
        }

        //查询信用评分是否提交
        StuCreditScoreExample creditScoreExample=new StuCreditScoreExample();
        creditScoreExample.createCriteria().andUserIdEqualTo(userId);
        List<StuCreditScore> stuCreditScores = stuCreditScoreMapper.selectByExample(creditScoreExample);
        if(stuCreditScores.isEmpty()){
            return false;
        }else {
            if(stuCreditScores.get(0).getSubmitStatus()!=1){
                return false;
            }
        }

        //查询征信方案是否已评分
        StuCreditEnhanceMeasureExample measureExample=new StuCreditEnhanceMeasureExample();
        measureExample.createCriteria().andUserIdEqualTo(userId);
        List<StuCreditEnhanceMeasure> stuCreditEnhanceMeasures = stuCreditEnhanceMeasureMapper.selectByExample(measureExample);
        if(stuCreditEnhanceMeasures.isEmpty()){
            return false;
        }
        return true;
    }
}
