package com.sztzjy.digital_credit.service.impl;/**
 * @author 17803
 * @date 2024-04-17 10:33
 */

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdUtil;
import com.sztzjy.digital_credit.entity.*;
import com.sztzjy.digital_credit.mapper.*;
import com.sztzjy.digital_credit.service.StuRateService;
import com.sztzjy.digital_credit.util.ResultEntity;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.util.*;

@Service
public class StuRateServiceImpl implements StuRateService {

    @Autowired
    private StuRatingModelMapper ratingModelMapper;

    @Autowired
    private StuRatingResultMapper resultMapper;

    @Autowired
    private StuCreditEnhanceMeasureMapper creditEnhanceMeasureMapper;

    @Autowired
    private StuBaseInfoMapper baseInfoMapper;

    @Autowired
    private StuCreditRecordsMapper creditRecordsMapper;


    @Autowired
    private StuDuPontAnalysisMapper duPontAnalysisMapper;

    @Autowired
    private StuGrowthAbilityMapper  growthAbilityMapper;

    @Autowired
    private StuOperatingCapacityMapper  operatingCapacityMapper;

    @Autowired
    private StuOperationAssetAnalysisModuleMapper  operationAssetAnalysisModuleMapper;

    @Autowired
    private StuProfitAbilityMapper  profitAbilityMapper;

    @Autowired
    private StuRatingResultMapper  ratingResultMapper;

    @Autowired
    private StuScoreModuleMapper  scoreModuleMapper;

    @Autowired
    private StuSolvencyMapper  solvencyMapper;

    @Autowired
    StuUserMapper userMapper;






    @Override
    public ResultEntity getRateInfo(String userId) {

        StuRatingModelExample ratingModelExample = new StuRatingModelExample();
        ratingModelExample.createCriteria().andUserIdEqualTo(userId);
        List<StuRatingModel> stuRatingModelList = ratingModelMapper.selectByExample(ratingModelExample);
        if (!stuRatingModelList.isEmpty())
        {
            return new ResultEntity<>(HttpStatus.OK,stuRatingModelList.get(0));
        }

        return new ResultEntity<>(HttpStatus.OK);
    }

    /**
        * 评级模型自动保存
        * @param ratingModel
        * @return
    */

    @Override
    public ResultEntity rateInfoBuAuto(StuRatingModel ratingModel) {


        //传过来用户未提交数据，根据提交状态进行判断，如果已经提交不修改

        StuRatingModelExample ratingModelExample = new StuRatingModelExample();
        ratingModelExample.createCriteria().andUserIdEqualTo(ratingModel.getUserId());
        List<StuRatingModel> stuRatingModelList = ratingModelMapper.selectByExample(ratingModelExample);
        if (!stuRatingModelList.isEmpty()){
            StuRatingModel info = stuRatingModelList.get(0);

            //防止前端传id为null

            String id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {


                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(ratingModel,info);

            info.setId(id);
            info.setUpdateTime(new Date());


            ratingModelMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

        //第一次保存没有用户数据


        ratingModel.setId(IdUtil.simpleUUID());
        ratingModel.setCreateTime(new Date());


        ratingModelMapper.insertSelective(ratingModel);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");
    }

    /**
        * 评级模型提交算分
        * @param ratingModel
        * @return
    */

    @Override
    public ResultEntity rateInfoBuSubCalculate(StuRatingModel ratingModel) {

        //判断是否为第一次提交
        StuRatingModelExample ratingModelExample = new StuRatingModelExample();
        ratingModelExample.createCriteria().andUserIdEqualTo(ratingModel.getUserId());
        List<StuRatingModel> stuRatingModelList = ratingModelMapper.selectByExample(ratingModelExample);
        if (!stuRatingModelList.isEmpty()){
            //有已提交用户数据
            if (stuRatingModelList.get(0).getSubState() == 1) {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);

            }

            //用户已经有了数据只能更新不能插入

            //首次提交判断输入数据是否则正确
            ratingModel =   resultCheckByRateInfoBuSubCalculate(ratingModel);
            ratingModel.setUpdateTime(new Date());
            ratingModel.setId(stuRatingModelList.get(0).getId());
            ratingModelMapper.updateByPrimaryKeySelective(ratingModel);
            //计算分数写入用户表
           enterScoreWriteUserByUserId(ratingModel,"评级模型",ratingModel.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",ratingModel.getErrorNumber());


        }else {
            //首次提交判断输入数据是否则正确
            ratingModel =   resultCheckByRateInfoBuSubCalculate(ratingModel);
            ratingModel.setId(IdUtil.simpleUUID());
            ratingModel.setCreateTime(new Date());

            //插入数据库
            ratingModelMapper.insertSelective(ratingModel);
            //计算分数写入用户表
            enterScoreWriteUserByUserId(ratingModel,"评级模型",ratingModel.getUserId());

            return new ResultEntity<>(HttpStatus.OK,"保存成功！",ratingModel.getErrorNumber());
        }
    }

    /**
        * 评级结果查询
        * @param userId
        * @return
    */

    @Override
    public ResultEntity getRateResultInfo(String userId) {

        StuRatingResultExample ratingResultExample = new StuRatingResultExample();
        ratingResultExample.createCriteria().andUserIdEqualTo(userId);
        List<StuRatingResult> ratingResultList = resultMapper.selectByExample(ratingResultExample);
        if (!ratingResultList.isEmpty())
        {
            return new ResultEntity<>(HttpStatus.OK,ratingResultList.get(0));
        }

        return new ResultEntity<>(HttpStatus.OK);
    }

    /**
        * 评级结果自动保存
        * @param ratingResult
        * @return
    */

    @Override
    public ResultEntity rateResultBuAutoSave(StuRatingResult ratingResult) {



        StuRatingResultExample ratingResultExample = new StuRatingResultExample();
        ratingResultExample.createCriteria().andUserIdEqualTo(ratingResult.getUserId());
        List<StuRatingResult> ratingResultList = resultMapper.selectByExample(ratingResultExample);
        if (!ratingResultList.isEmpty()) {

            StuRatingResult info = ratingResultList.get(0);

            //防止前端传id为null

            String id = info.getId();

            if (info.getSubState() == null)
            {
                info.setSubState(0);
            }
            //有已提交用户数据
            if (info.getSubState() == 1)
            {
                //不做任何修改
                return new ResultEntity<>(HttpStatus.OK);
            }

            //未提交，但是有数据,同步最新数据

            BeanUtils.copyProperties(ratingResult,info);

            info.setId(id);
            info.setUpdateTime(new Date());


            resultMapper.updateByPrimaryKeySelective(info);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }

        //第一次保存没有用户数据


        ratingResult.setId(IdUtil.simpleUUID());
        ratingResult.setCreateTime(new Date());


        resultMapper.insertSelective(ratingResult);

        return new ResultEntity<>(HttpStatus.OK,"保存成功！");


    }

    /**
        * 评级结果提交算分
        * @param ratingResult
        * @return
    */

    @Override
    public ResultEntity rateResultBySubCalculate(StuRatingResult ratingResult) {
        StuRatingResultExample ratingResultExample = new StuRatingResultExample();
        ratingResultExample.createCriteria().andUserIdEqualTo(ratingResult.getUserId());
        List<StuRatingResult> ratingResultList = resultMapper.selectByExample(ratingResultExample);
        if (!ratingResultList.isEmpty()) {

                //有已提交用户数据
                if (ratingResultList.get(0).getSubState() == 1) {
                    //不做任何修改
                    return new ResultEntity<>(HttpStatus.OK);

                }

                //用户已经有了数据只能更新不能插入
                //首次提交判断输入数据是否则正确
            ratingResult =   resultCheckByrateResult(ratingResult);
            ratingResult.setUpdateTime(new Date());
            ratingResult.setId(ratingResultList.get(0).getId());
            resultMapper.updateByPrimaryKeySelective(ratingResult);
            //计算分数写入用户表
            enterScoreWriteUserByUserId(ratingResult,"评级结果",ratingResult.getUserId());
                return new ResultEntity<>(HttpStatus.OK,"保存成功！",ratingResult.getErrorNumber());


            }else {
                //首次提交判断输入数据是否则正确
            ratingResult =   resultCheckByrateResult(ratingResult);
            ratingResult.setId(IdUtil.simpleUUID());
            ratingResult.setCreateTime(new Date());

                //插入数据库
            resultMapper.insertSelective(ratingResult);
            //计算分数写入用户表
           enterScoreWriteUserByUserId(ratingResult,"评级结果",ratingResult.getUserId());
            return new ResultEntity<>(HttpStatus.OK,"保存成功！",ratingResult.getErrorNumber());

            }

    }

    /**
        * 增信措施自动评分
        * @param enhanceMeasure
        * @return
    */

    @Override
    public ResultEntity enhanceMeasureByAutoRating(StuCreditEnhanceMeasure enhanceMeasure) {
        StuCreditEnhanceMeasureExample enhanceMeasureExample = new StuCreditEnhanceMeasureExample();
        enhanceMeasureExample.createCriteria().andUserIdEqualTo(enhanceMeasure.getUserId()).andModuleEqualTo(enhanceMeasure.getModule());
        List<StuCreditEnhanceMeasure> creditEnhanceMeasureList = creditEnhanceMeasureMapper.selectByExample(enhanceMeasureExample);

        if (!creditEnhanceMeasureList.isEmpty()){


            //判断老师是否评分，已经评分不修改
            if (creditEnhanceMeasureList.get(0).getTchScore()!= -1)
            {
                return new ResultEntity<>(HttpStatus.OK,"保存失败,教师已经评分！");
            }


            creditEnhanceMeasureList.get(0).setEnchancePlan(enhanceMeasure.getEnchancePlan());

            //   智能评分  //插入user表企业征信主观成绩数据
            int scoreByAuto = enchancePlanAutoScore(enhanceMeasure.getEnchancePlan().length(),enhanceMeasure.getUserId(),enhanceMeasure.getModule());

            creditEnhanceMeasureList.get(0).setSysScore(scoreByAuto);

            creditEnhanceMeasureList.get(0).setUpdateTime(new Date());

            creditEnhanceMeasureList.get(0).setErrorNumber(20-scoreByAuto);


            creditEnhanceMeasureMapper.updateByPrimaryKeySelective(creditEnhanceMeasureList.get(0));

            return new ResultEntity<>(HttpStatus.OK,"保存成功",scoreByAuto);
        }

        //首次插入
        enhanceMeasure.setId(IdUtil.simpleUUID());
        enhanceMeasure.setCreateTime(new Date());
        int length = enhanceMeasure.getEnchancePlan().length();

        // TODO: 2024/4/17  智能评分
        int scoreByAuto = enchancePlanAutoScore(length,enhanceMeasure.getUserId(),enhanceMeasure.getModule());

        enhanceMeasure.setSysScore(scoreByAuto);

        enhanceMeasure.setTchScore(-1);

        enhanceMeasure.setErrorNumber(20-scoreByAuto);

        creditEnhanceMeasureMapper.insertSelective(enhanceMeasure);


        return new ResultEntity<>(HttpStatus.OK,"保存成功！",scoreByAuto);
    }

    /**
        * 企业征信:重新实训
        * @param userId
        * @return
    */

    @Override
    public ResultEntity enterpriseRetraining(String userId) {


        StuBaseInfoExample stuBaseInfoExample = new StuBaseInfoExample();
        stuBaseInfoExample.createCriteria().andUserIdEqualTo(userId);
        baseInfoMapper.deleteByExample(stuBaseInfoExample);


        StuCreditEnhanceMeasureExample stuCreditEnhanceMeasureExample = new StuCreditEnhanceMeasureExample();
        stuCreditEnhanceMeasureExample.createCriteria().andUserIdEqualTo(userId);
        creditEnhanceMeasureMapper.deleteByExample(stuCreditEnhanceMeasureExample);


        StuCreditRecordsExample stuCreditRecordsExample = new StuCreditRecordsExample();
        stuCreditRecordsExample.createCriteria().andUserIdEqualTo(userId);
        creditRecordsMapper.deleteByExample(stuCreditRecordsExample);


        StuDuPontAnalysisExample stuDuPontAnalysisExample = new StuDuPontAnalysisExample();
        stuDuPontAnalysisExample.createCriteria().andUserIdEqualTo(userId);
        duPontAnalysisMapper.deleteByExample(stuDuPontAnalysisExample);



        StuGrowthAbilityExample stuGrowthAbilityExample = new StuGrowthAbilityExample();
        stuGrowthAbilityExample.createCriteria().andUserIdEqualTo(userId);
        growthAbilityMapper.deleteByExample(stuGrowthAbilityExample);


        StuOperatingCapacityExample stuOperatingCapacityExample = new StuOperatingCapacityExample();
        stuOperatingCapacityExample.createCriteria().andUserIdEqualTo(userId);
        operatingCapacityMapper.deleteByExample(stuOperatingCapacityExample);


        StuOperationAssetAnalysisModuleExample stuOperationAssetAnalysisModuleExample = new StuOperationAssetAnalysisModuleExample();
        stuOperationAssetAnalysisModuleExample.createCriteria().andUserIdEqualTo(userId);
        operationAssetAnalysisModuleMapper.deleteByExample(stuOperationAssetAnalysisModuleExample);


        StuProfitAbilityExample stuProfitAbilityExample = new StuProfitAbilityExample();
        stuProfitAbilityExample.createCriteria().andUserIdEqualTo(userId);
        profitAbilityMapper.deleteByExample(stuProfitAbilityExample);

        StuRatingModelExample ratingModelExample = new StuRatingModelExample();
        ratingModelExample.createCriteria().andUserIdEqualTo(userId);
        ratingModelMapper.deleteByExample(ratingModelExample);


        StuRatingResultExample stuRatingResultExample = new StuRatingResultExample();
        stuRatingResultExample.createCriteria().andUserIdEqualTo(userId);
        ratingResultMapper.deleteByExample(stuRatingResultExample);


        StuScoreModuleExample stuScoreModuleExample = new StuScoreModuleExample();
        stuScoreModuleExample.createCriteria().andUserIdEqualTo(userId);
        scoreModuleMapper.deleteByExample(stuScoreModuleExample);


        StuSolvencyExample stuSolvencyExample = new StuSolvencyExample();
        stuSolvencyExample.createCriteria().andUserIdEqualTo(userId);
        solvencyMapper.deleteByExample(stuSolvencyExample);


        return new ResultEntity<>(HttpStatus.OK);
    }

    /**
        * 企业征信完成状态
        * @param userId
        * @return
    */

    @Override
    public Boolean completionStatusOfEnterprise(String userId) {

        ArrayList<Integer> arrayList = new ArrayList<>();

        StuBaseInfoExample stuBaseInfoExample = new StuBaseInfoExample();
        stuBaseInfoExample.createCriteria().andUserIdEqualTo(userId);
        List<StuBaseInfo> stuBaseInfoList = baseInfoMapper.selectByExample(stuBaseInfoExample);
        if (!stuBaseInfoList.isEmpty()){
            if (stuBaseInfoList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }

        }else {
            arrayList.add(0);
        }


        StuCreditEnhanceMeasureExample stuCreditEnhanceMeasureExample = new StuCreditEnhanceMeasureExample();
        stuCreditEnhanceMeasureExample.createCriteria().andUserIdEqualTo(userId);
        List<StuCreditEnhanceMeasure> creditEnhanceMeasureList = creditEnhanceMeasureMapper.selectByExample(stuCreditEnhanceMeasureExample);
        if (creditEnhanceMeasureList.isEmpty()){
            arrayList.add(0);
        }


        StuCreditRecordsExample stuCreditRecordsExample = new StuCreditRecordsExample();
        stuCreditRecordsExample.createCriteria().andUserIdEqualTo(userId);
        List<StuCreditRecords> stuCreditRecordsList = creditRecordsMapper.selectByExample(stuCreditRecordsExample);
        if (!stuCreditRecordsList.isEmpty()){
            if (stuBaseInfoList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }

        }else {
            arrayList.add(0);
        }


        StuDuPontAnalysisExample stuDuPontAnalysisExample = new StuDuPontAnalysisExample();
        stuDuPontAnalysisExample.createCriteria().andUserIdEqualTo(userId);
        List<StuDuPontAnalysis> duPontAnalysisList = duPontAnalysisMapper.selectByExample(stuDuPontAnalysisExample);
        if (!duPontAnalysisList.isEmpty()){
            if (duPontAnalysisList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }

        }else {
            arrayList.add(0);
        }


        StuGrowthAbilityExample stuGrowthAbilityExample = new StuGrowthAbilityExample();
        stuGrowthAbilityExample.createCriteria().andUserIdEqualTo(userId);
        List<StuGrowthAbility> growthAbilityList = growthAbilityMapper.selectByExample(stuGrowthAbilityExample);
        if (!growthAbilityList.isEmpty()){
            if (growthAbilityList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }

        }else {
            arrayList.add(0);
        }


        StuOperatingCapacityExample stuOperatingCapacityExample = new StuOperatingCapacityExample();
        stuOperatingCapacityExample.createCriteria().andUserIdEqualTo(userId);
        List<StuOperatingCapacity> operatingCapacityList = operatingCapacityMapper.selectByExample(stuOperatingCapacityExample);
        if (!operatingCapacityList.isEmpty()){
            if (operatingCapacityList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuOperationAssetAnalysisModuleExample stuOperationAssetAnalysisModuleExample = new StuOperationAssetAnalysisModuleExample();
        stuOperationAssetAnalysisModuleExample.createCriteria().andUserIdEqualTo(userId);
        List<StuOperationAssetAnalysisModule> operationAssetAnalysisModuleList = operationAssetAnalysisModuleMapper.selectByExample(stuOperationAssetAnalysisModuleExample);
        if (!operationAssetAnalysisModuleList.isEmpty()){
            if (operationAssetAnalysisModuleList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuProfitAbilityExample stuProfitAbilityExample = new StuProfitAbilityExample();
        stuProfitAbilityExample.createCriteria().andUserIdEqualTo(userId);
        List<StuProfitAbility> profitAbilityList = profitAbilityMapper.selectByExample(stuProfitAbilityExample);
        if (!profitAbilityList.isEmpty()){
            if (profitAbilityList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuRatingModelExample ratingModelExample = new StuRatingModelExample();
        ratingModelExample.createCriteria().andUserIdEqualTo(userId);
        List<StuRatingModel> stuRatingModelList = ratingModelMapper.selectByExample(ratingModelExample);
        if (!stuRatingModelList.isEmpty()){
            if (stuRatingModelList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuRatingResultExample stuRatingResultExample = new StuRatingResultExample();
        stuRatingResultExample.createCriteria().andUserIdEqualTo(userId);
        List<StuRatingResult> ratingResultList = ratingResultMapper.selectByExample(stuRatingResultExample);
        if (!ratingResultList.isEmpty()){
            if (ratingResultList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuScoreModuleExample stuScoreModuleExample = new StuScoreModuleExample();
        stuScoreModuleExample.createCriteria().andUserIdEqualTo(userId);
        List<StuScoreModule> scoreModuleList = scoreModuleMapper.selectByExample(stuScoreModuleExample);
        if (!scoreModuleList.isEmpty()){
            if (scoreModuleList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }


        StuSolvencyExample stuSolvencyExample = new StuSolvencyExample();
        stuSolvencyExample.createCriteria().andUserIdEqualTo(userId);
        List<StuSolvency> stuSolvencyList = solvencyMapper.selectByExample(stuSolvencyExample);
        if (!stuSolvencyList.isEmpty()){
            if (stuSolvencyList.get(0).getSubState() != 1) {
                arrayList.add(0);
            }
        }else {
            arrayList.add(0);
        }
        for (Integer integer : arrayList) {
            if (integer == 0)
            {
                return false;
            }
        }


        return true;
    }

    //增信措施自动评分
    private int enchancePlanAutoScore(int length,String userId,String module) {

        //50字以内5分，每多10个字多1分，上限20分
        int baseScore = 5;
        int additionalScore = (length > 50) ? (length - 50) / 10 : 0;
        int score = baseScore + additionalScore;
        int min = Math.min(score, 20);

        StuUserExample userExample = new StuUserExample();
        userExample.createCriteria().andUserIdEqualTo(userId);
        List<StuUser> stuUsers = userMapper.selectByExample(userExample);
        if (!stuUsers.isEmpty()){
            //将自动评分成绩写入对应成绩
            if ("个人征信".equals(module)){
                stuUsers.get(0).setCasePersonalCreditScore(BigDecimal.valueOf(min));
            }
            if ("企业征信".equals(module)){
                stuUsers.get(0).setCaseCorporateCreditSubScore(BigDecimal.valueOf(min));
            }

            userMapper.updateByPrimaryKeySelective(stuUsers.get(0));
        }


        return Math.min(score, 20); // 上限20分
    }

    //评级结果提交算分
    private StuRatingResult resultCheckByrateResult(StuRatingResult ratingResult) {

        int sum = 0;

        //初步评级总分
        if (!"93".equals(ratingResult.getPreliminaryRatingTotalScore()))
        {
            sum = sum + 2;
        }

        //调整项总分
        if (!"6".equals(ratingResult.getTotalScoreOfAdjustItems()))
        {
            sum = sum + 2;
        }

        //最终总分
        if (!"99".equals(ratingResult.getFinalTotalScore()))
        {
           sum ++;
        }

        //信用等级
        if (!"AA".equals(ratingResult.getCreditRating()))
        {
            sum ++;
        }

        ratingResult.setErrorNumber(sum);
        ratingResult.setSubState(1);
        return ratingResult;

    }


    //评级模型提交算分
    private StuRatingModel resultCheckByRateInfoBuSubCalculate(StuRatingModel ratingModel) {


        int sum = 0;
        //正确答案
        String[] array = {"4","2", "4","2","2","1","3","4","3","3","4","5", "3","4","3","3","4","3", "4","4","3","1","12","8","4", "0","0","0","0","-1","0","0","0","5","2","99"};

        String[] stuAnswer = ratingModel.getStuAnswer().split(",");
        for (int i = 0; i < stuAnswer.length; i++) {

            if (stuAnswer[i].equals("null"))
            {
                sum ++;
                continue;
            }

            if (!array[i].equals( stuAnswer[i]))
            {
                sum ++;
            }


        }


        ratingModel.setErrorNumber(sum);
        ratingModel.setSubState(1);
        return ratingModel;

    }



    //企业征信将成绩写入用户表，计算总成绩
    public  void enterScoreWriteUserByUserId(Object obj,String module,String userId) {


        Class<?> aClass = obj.getClass();


        try {
            //判断提交状态是否为1
            Field subState = aClass.getDeclaredField("subState");
            subState.setAccessible(true);

            Object state = subState.get(obj);
            //不为1返回
            if (!state.equals(1)){
                return ;
            }


            // 获取错误次数的属性
            Field field = aClass.getDeclaredField("errorNumber");
            // 设置访问权限，允许访问私有属性
            field.setAccessible(true);
            //获取错误次数
            Object errorCount = field.get(obj);


            HashMap<String, Integer> map = new HashMap<>();
            map.put("基本信息",24);
            map.put("信贷记录",16);
            map.put("盈利能力",7);
            map.put("偿债能力",7);
            map.put("营运能力",8);
            map.put("成长能力",1);
            map.put("杜邦分析",4);
            map.put("Z计分模型",12);
            map.put("营运资产分析模型",10);
            map.put("评级模型",35);
            map.put("评级结果",6);




            Integer currentCount = map.get(module);

            //获取正确得分
            Integer info =  currentCount - Convert.toInt(errorCount);
            if (info<= 0 )
            {
                info = 0;
            }



            StuUser user =  userMapper.selectByPrimaryKey(userId);
            //获取用户企业征信客观成绩
            BigDecimal caseCorporateCreditObjScore = user.getCaseCorporateCreditObjScore();
            if (user.getCaseCorporateCreditObjScore() == null){
                caseCorporateCreditObjScore   = BigDecimal.valueOf(0);
            }

            caseCorporateCreditObjScore =  caseCorporateCreditObjScore.add(BigDecimal.valueOf(info));
            //赋值企业征信客观成绩
            user.setCaseCorporateCreditObjScore(caseCorporateCreditObjScore);
            //获取企业征信客观总成绩
            BigDecimal caseCorporateCreditScore = user.getCaseCorporateCreditScore();
            if (caseCorporateCreditScore == null){
                caseCorporateCreditScore   = BigDecimal.valueOf(0);
            }
            //赋值企业征信客观总的成绩
            user.setCaseCorporateCreditScore(caseCorporateCreditScore.add(BigDecimal.valueOf(info)));

            userMapper.updateByPrimaryKeySelective(user);



        } catch (Exception e) {
            throw new RuntimeException(e);
        }


    }





}
