package com.sztzjy.digital_credit.service.impl;/**
 * @author 17803
 * @date 2024-04-23 14:11
 */

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdUtil;
import com.sztzjy.digital_credit.entity.StuUser;
import com.sztzjy.digital_credit.entity.StuUserExample;
import com.sztzjy.digital_credit.entity.StuUserPortrait;
import com.sztzjy.digital_credit.entity.StuUserPortraitExample;
import com.sztzjy.digital_credit.mapper.StuUserMapper;
import com.sztzjy.digital_credit.mapper.StuUserPortraitMapper;
import com.sztzjy.digital_credit.service.StuUserPortraitControllerService;
import com.sztzjy.digital_credit.util.ResultEntity;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.rmi.ServerException;
import java.util.HashMap;
import java.util.List;

@Service
public class StuUserPortraitControllerServiceImpl implements StuUserPortraitControllerService {


    @Autowired
    private StuUserPortraitMapper userPortraitMapper;

    @Autowired
    private StuUserMapper userMapper;

    /**
        * 自动保存接口(根据module分类)
        * @param userPortrait
        * @return
    */

    @Override
    public ResultEntity userPortraitByModuleSave(StuUserPortrait userPortrait) {

        StuUserPortraitExample portraitExample = new StuUserPortraitExample();
        portraitExample.createCriteria().andUserIdEqualTo(userPortrait.getUserId()).andModuleEqualTo(userPortrait.getModule());
        List<StuUserPortrait> userPortraitList = userPortraitMapper.selectByExample(portraitExample);
        if (!userPortraitList.isEmpty()) {

            if (userPortraitList.get(0).getSubState() == 1)
            {
                return new ResultEntity<>(HttpStatus.OK,"保存成功！");
            }
            //更新
            StuUserPortrait portrait = userPortraitList.get(0);
            Integer id = portrait.getId();
            BeanUtils.copyProperties(userPortrait,portrait);
            portrait.setId(id);

            //判断是否为提交状态，是提交状态
            if (portrait.getSubState() == 1)
            {
                //根据model算正确分数
                portrait =    correctScoreCalculationByModule(portrait);

                //将分数保存到用户表，如果重新实训将用户表数据删除
                 saveScoreToUser(portrait);
            }

            userPortraitMapper.updateByPrimaryKeySelective(portrait);

            return new ResultEntity<>(HttpStatus.OK,"保存成功！");

        }else {
            //插入
            userPortrait.setId((int) IdUtil.getSnowflakeNextId());

            //判断是否为提交状态，是提交状态
            if (userPortrait.getSubState() == 1)
            {
                //根据model算正确分数
                userPortrait =    correctScoreCalculationByModule(userPortrait);

                //将分数保存到用户表，如果重新实训将用户表数据删除
                saveScoreToUser(userPortrait);
            }

            userPortraitMapper.insertSelective(userPortrait);
            //判断是否为提交状态，是提交状态将分数保存到用户表，如果重新实训将用户表数据删除
            return new ResultEntity<>(HttpStatus.OK,"保存成功！");
        }

    }

    /**
        * 用户画像提交状态
        * @param userId
        * @return
    */

    @Override
    public Boolean userPortraitSubState(String userId) {

        StuUserPortraitExample portraitExample = new StuUserPortraitExample();
        portraitExample.createCriteria().andUserIdEqualTo(userId);
        List<StuUserPortrait> userPortraitList = userPortraitMapper.selectByExample(portraitExample);
        if (!userPortraitList.isEmpty()) {
            if (userPortraitList.size() == 7 )
            {
                return true;
            }

            return false;

        }

        return false;
    }


    //将分数保存到用户表，如果重新实训将用户表数据删除
    private void saveScoreToUser(StuUserPortrait portrait) {
        StuUserExample userExample = new StuUserExample();
        userExample.createCriteria().andUserIdEqualTo(portrait.getUserId());
        List<StuUser> stuUsers = userMapper.selectByExample(userExample);
        if (!stuUsers.isEmpty())
        {
            //获取用户总分累加
            BigDecimal caseUserProfileSocre = stuUsers.get(0).getCaseUserProfileSocre();

            Integer correctNumber = portrait.getCorrectNumber();

            stuUsers.get(0).setCaseUserProfileSocre(caseUserProfileSocre.add(Convert.toBigDecimal(correctNumber)));

            userMapper.updateByPrimaryKeySelective(stuUsers.get(0));

        }

        throw new RuntimeException("用户信息不存在！");


    }


    //根据model算正确分数
    private StuUserPortrait correctScoreCalculationByModule(StuUserPortrait portrait) {

        HashMap<String, Integer> map = new HashMap<>();
        map.put("违约情况",6);
        map.put("性别与违约分析",11);
        map.put("学历与违约分析",12);
        map.put("婚姻状况与违约分析",12);
        map.put("年龄与违约分析",17);
        map.put("还款状况与违约分析",23);
        map.put("信用额度与违约分析",19);


        Integer currentCount = map.get(portrait.getModule());

        int score = currentCount - portrait.getErrorNumber();

        if (score <= 0)
        {
            score = 0;
        }

        portrait.setCorrectNumber(score);

        return portrait;
    }


}
