package com.sztzjy.digital_credit.util;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.read.listener.ReadListener;
import com.alibaba.excel.util.ListUtils;
import com.sztzjy.digital_credit.entity.StuFinancialStatements;
import com.sztzjy.digital_credit.mapper.StuFinancialStatementsMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

public class MyExcelListener implements ReadListener<StuFinancialStatements> {


    private StuFinancialStatementsMapper financialStatementsMapper;

    private String module;





    /**
     * 每隔5条存储数据库，实际使用中可以100条，然后清理list ，方便内存回收
     */
    private static final int BATCH_COUNT = 100;
    /**
     * 缓存的数据
     */
    private List<StuFinancialStatements> cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);


    public MyExcelListener(StuFinancialStatementsMapper financialStatementsMapper, String module) {
        this.financialStatementsMapper = financialStatementsMapper;
        this.module = module;
    }

    int i = 1;
    @Override
    public void invoke(StuFinancialStatements person, AnalysisContext analysisContext) {
        //System.out.println(person);
        person.setModule(module);
        person.setCreateTime(new Date());

        person.setSerialNumber(i++);
        cachedDataList.add(person);



        // 达到BATCH_COUNT了，需要去存储一次数据库，防止数据几万条数据在内存，容易OOM
        if (cachedDataList.size() >= BATCH_COUNT) {
            // 写入数据库
            // saveData();
            // 存储完成清理 list
            cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        // 这里也要保存数据，确保最后遗留的数据也存储到数据库
        // saveData();
        financialStatementsMapper.batchInsertExcel(cachedDataList);
        System.out.println("解析完成");
    }

    // 异常处理
    @Override
    public void onException(Exception exception, AnalysisContext context) throws Exception {
        ReadListener.super.onException(exception, context);
    }

}